import { createRouteRef, createApiRef, useApi, errorApiRef, createPlugin, createApiFactory, discoveryApiRef, configApiRef, identityApiRef, createComponentExtension } from '@backstage/core-plugin-api';
import globalAxios, { isAxiosError, AxiosError } from 'axios';
import 'ua-parser-js';
import React, { useState, useEffect, createContext, useContext, useCallback, useRef, useLayoutEffect, Component, useMemo, forwardRef } from 'react';
import { ValiError, optional, union, literal, undefined_, object, string, record, parse } from 'valibot';
import { scmIntegrationsApiRef } from '@backstage/integration-react';
import { useEntity, getEntitySourceLocation } from '@backstage/plugin-catalog-react';
import { createPortal } from 'react-dom';
import { useQuery, useQueryClient, QueryClient, QueryClientProvider } from '@tanstack/react-query';
import { makeStyles } from '@material-ui/core';
import { LinkButton, Link } from '@backstage/core-components';
import Dialog from '@material-ui/core/Dialog';
import DialogContent from '@material-ui/core/DialogContent';
import DialogTitle from '@material-ui/core/DialogTitle';
import DialogActions from '@material-ui/core/DialogActions';
import TextField from '@material-ui/core/TextField';
import ErrorIcon from '@material-ui/icons/ErrorOutline';
import SyncIcon from '@material-ui/icons/Sync';

const rootRouteRef = createRouteRef({
  id: "coder"
});

const CODER_API_REF_ID_PREFIX = "backstage-plugin-coder";
const DEFAULT_TANSTACK_QUERY_RETRY_COUNT = 3;

var __defProp$3 = Object.defineProperty;
var __defNormalProp$3 = (obj, key, value) => key in obj ? __defProp$3(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField$3 = (obj, key, value) => {
  __defNormalProp$3(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
function areSameByReference(v1, v2) {
  return Object.is(v1, v2) || v1 === 0 && v2 === 0;
}
function defaultDidSnapshotsChange(oldSnapshot, newSnapshot) {
  if (areSameByReference(oldSnapshot, newSnapshot)) {
    return false;
  }
  const oldIsPrimitive = typeof oldSnapshot !== "object" || oldSnapshot === null;
  const newIsPrimitive = typeof newSnapshot !== "object" || newSnapshot === null;
  if (oldIsPrimitive && newIsPrimitive) {
    const numbersAreWithinTolerance = typeof oldSnapshot === "number" && typeof newSnapshot === "number" && Math.abs(oldSnapshot - newSnapshot) < 5e-5;
    if (numbersAreWithinTolerance) {
      return false;
    }
    return oldSnapshot !== newSnapshot;
  }
  const changedFromObjectToPrimitive = !oldIsPrimitive && newIsPrimitive;
  const changedFromPrimitiveToObject = oldIsPrimitive && !newIsPrimitive;
  if (changedFromObjectToPrimitive || changedFromPrimitiveToObject) {
    return true;
  }
  if (Array.isArray(oldSnapshot) && Array.isArray(newSnapshot)) {
    const sameByShallowComparison = oldSnapshot.length === newSnapshot.length && oldSnapshot.every(
      (element, index) => areSameByReference(element, newSnapshot[index])
    );
    return !sameByShallowComparison;
  }
  const oldInnerValues = Object.values(oldSnapshot);
  const newInnerValues = Object.values(newSnapshot);
  if (oldInnerValues.length !== newInnerValues.length) {
    return true;
  }
  for (const [index, value] of oldInnerValues.entries()) {
    if (value !== newInnerValues[index]) {
      return true;
    }
  }
  return false;
}
class StateSnapshotManager {
  constructor(options) {
    __publicField$3(this, "subscriptions");
    __publicField$3(this, "didSnapshotsChange");
    __publicField$3(this, "activeSnapshot");
    __publicField$3(this, "unsubscribe", (callback) => {
      this.subscriptions.delete(callback);
    });
    __publicField$3(this, "subscribe", (callback) => {
      this.subscriptions.add(callback);
      return () => this.unsubscribe(callback);
    });
    __publicField$3(this, "getSnapshot", () => {
      return this.activeSnapshot;
    });
    __publicField$3(this, "updateSnapshot", (newSnapshot) => {
      const snapshotsChanged = this.didSnapshotsChange(
        this.activeSnapshot,
        newSnapshot
      );
      if (!snapshotsChanged) {
        return;
      }
      this.activeSnapshot = newSnapshot;
      this.notifySubscriptions();
    });
    const { initialSnapshot, didSnapshotsChange } = options;
    this.subscriptions = /* @__PURE__ */ new Set();
    this.activeSnapshot = initialSnapshot;
    this.didSnapshotsChange = didSnapshotsChange != null ? didSnapshotsChange : defaultDidSnapshotsChange;
  }
  notifySubscriptions() {
    const snapshotBinding = this.activeSnapshot;
    this.subscriptions.forEach((cb) => cb(snapshotBinding));
  }
}

var __defProp$2 = Object.defineProperty;
var __defNormalProp$2 = (obj, key, value) => key in obj ? __defProp$2(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField$2 = (obj, key, value) => {
  __defNormalProp$2(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
const CODER_PROXY_PREFIX = "/coder";
const BASE_URL_KEY_FOR_CONFIG_API = "backend.baseUrl";
const PROXY_URL_KEY_FOR_DISCOVERY_API = "proxy";
const defaultUrlPrefixes = {
  proxyPrefix: `/api/proxy`
};
const proxyRouteReplacer = /\/api\/proxy.*?$/;
class UrlSync {
  constructor(setup) {
    __publicField$2(this, "discoveryApi");
    __publicField$2(this, "urlCache");
    __publicField$2(this, "urlPrefixes");
    /* ***************************************************************************
     * All public functions should be defined as arrow functions to ensure they
     * can be passed around React without risk of losing their `this` context
     ****************************************************************************/
    __publicField$2(this, "getApiEndpoint", async () => {
      const proxyRoot = await this.discoveryApi.getBaseUrl(
        PROXY_URL_KEY_FOR_DISCOVERY_API
      );
      const newSnapshot = this.prepareNewSnapshot(proxyRoot);
      this.urlCache.updateSnapshot(newSnapshot);
      return newSnapshot.apiRoute;
    });
    __publicField$2(this, "getAssetsEndpoint", async () => {
      const proxyRoot = await this.discoveryApi.getBaseUrl(
        PROXY_URL_KEY_FOR_DISCOVERY_API
      );
      const newSnapshot = this.prepareNewSnapshot(proxyRoot);
      this.urlCache.updateSnapshot(newSnapshot);
      return newSnapshot.assetsRoute;
    });
    __publicField$2(this, "getCachedUrls", () => {
      return this.urlCache.getSnapshot();
    });
    __publicField$2(this, "unsubscribe", (callback) => {
      this.urlCache.unsubscribe(callback);
    });
    __publicField$2(this, "subscribe", (callback) => {
      this.urlCache.subscribe(callback);
      return () => this.unsubscribe(callback);
    });
    const { apis, urlPrefixes = {} } = setup;
    const { discoveryApi, configApi } = apis;
    this.discoveryApi = discoveryApi;
    this.urlPrefixes = { ...defaultUrlPrefixes, ...urlPrefixes };
    const proxyRoot = this.getProxyRootFromConfigApi(configApi);
    this.urlCache = new StateSnapshotManager({
      initialSnapshot: this.prepareNewSnapshot(proxyRoot)
    });
  }
  // ConfigApi is literally only used because it offers a synchronous way to
  // get an initial URL to use from inside the constructor. Should not be used
  // beyond initial constructor call, so it's not being embedded in the class
  getProxyRootFromConfigApi(configApi) {
    const baseUrl = configApi.getString(BASE_URL_KEY_FOR_CONFIG_API);
    return `${baseUrl}${this.urlPrefixes.proxyPrefix}`;
  }
  prepareNewSnapshot(newProxyUrl) {
    return {
      baseUrl: newProxyUrl.replace(proxyRouteReplacer, ""),
      assetsRoute: `${newProxyUrl}${CODER_PROXY_PREFIX}`,
      apiRoute: `${newProxyUrl}${CODER_PROXY_PREFIX}`
    };
  }
}
const urlSyncApiRef = createApiRef({
  id: `${CODER_API_REF_ID_PREFIX}.url-sync`
});

const delay = (ms) => new Promise((res) => {
  setTimeout(res, ms);
});

const FeatureNames = [
  "access_control",
  "advanced_template_scheduling",
  "appearance",
  "audit_log",
  "browser_only",
  "control_shared_ports",
  "custom_roles",
  "external_provisioner_daemons",
  "external_token_encryption",
  "high_availability",
  "multiple_external_auth",
  "scim",
  "template_rbac",
  "user_limit",
  "user_role_management",
  "workspace_batch_actions",
  "workspace_proxy"
];

var __defProp$1 = Object.defineProperty;
var __defNormalProp$1 = (obj, key, value) => key in obj ? __defProp$1(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField$1 = (obj, key, value) => {
  __defNormalProp$1(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
const getMissingParameters = (oldBuildParameters, newBuildParameters, templateParameters) => {
  const missingParameters = [];
  const requiredParameters = [];
  templateParameters.forEach((p) => {
    const isMutableAndRequired = p.mutable && p.required;
    const isImmutable = !p.mutable;
    if (isMutableAndRequired || isImmutable) {
      requiredParameters.push(p);
    }
  });
  for (const parameter of requiredParameters) {
    let buildParameter = newBuildParameters.find(
      (p) => p.name === parameter.name
    );
    if (!buildParameter) {
      buildParameter = oldBuildParameters.find((p) => p.name === parameter.name);
    }
    if (buildParameter) {
      continue;
    }
    missingParameters.push(parameter);
  }
  templateParameters.forEach((templateParameter) => {
    if (templateParameter.options.length === 0) {
      return;
    }
    let buildParameter = newBuildParameters.find(
      (p) => p.name === templateParameter.name
    );
    if (!buildParameter) {
      buildParameter = oldBuildParameters.find(
        (p) => p.name === templateParameter.name
      );
    }
    if (!buildParameter) {
      return;
    }
    const matchingOption = templateParameter.options.find(
      (option) => option.value === (buildParameter == null ? void 0 : buildParameter.value)
    );
    if (!matchingOption) {
      missingParameters.push(templateParameter);
    }
  });
  return missingParameters;
};
const getURLWithSearchParams = (basePath, options) => {
  if (!options) {
    return basePath;
  }
  const searchParams = new URLSearchParams();
  const keys = Object.keys(options);
  keys.forEach((key) => {
    const value = options[key];
    if (value !== void 0 && value !== "") {
      searchParams.append(key, value.toString());
    }
  });
  const searchString = searchParams.toString();
  return searchString ? `${basePath}?${searchString}` : basePath;
};
const withDefaultFeatures = (fs) => {
  for (const feature of FeatureNames) {
    if (fs[feature] !== void 0) {
      continue;
    }
    fs[feature] = {
      enabled: false,
      entitlement: "not_entitled"
    };
  }
  return fs;
};
const BASE_CONTENT_TYPE_JSON = {
  "Content-Type": "application/json"
};
class MissingBuildParameters extends Error {
  constructor(parameters, versionId) {
    super("Missing build parameters.");
    __publicField$1(this, "parameters", []);
    __publicField$1(this, "versionId");
    this.parameters = parameters;
    this.versionId = versionId;
  }
}
class ApiMethods {
  constructor(axios) {
    this.axios = axios;
    __publicField$1(this, "login", async (email, password) => {
      const payload = JSON.stringify({ email, password });
      const response = await this.axios.post(
        "/api/v2/users/login",
        payload,
        { headers: { ...BASE_CONTENT_TYPE_JSON } }
      );
      return response.data;
    });
    __publicField$1(this, "convertToOAUTH", async (request) => {
      const response = await this.axios.post(
        "/api/v2/users/me/convert-login",
        request
      );
      return response.data;
    });
    __publicField$1(this, "logout", async () => {
      return this.axios.post("/api/v2/users/logout");
    });
    __publicField$1(this, "getAuthenticatedUser", async () => {
      const response = await this.axios.get("/api/v2/users/me");
      return response.data;
    });
    __publicField$1(this, "getUserParameters", async (templateID) => {
      const response = await this.axios.get(
        `/api/v2/users/me/autofill-parameters?template_id=${templateID}`
      );
      return response.data;
    });
    __publicField$1(this, "getAuthMethods", async () => {
      const response = await this.axios.get(
        "/api/v2/users/authmethods"
      );
      return response.data;
    });
    __publicField$1(this, "getUserLoginType", async () => {
      const response = await this.axios.get(
        "/api/v2/users/me/login-type"
      );
      return response.data;
    });
    __publicField$1(this, "checkAuthorization", async (params) => {
      const response = await this.axios.post(
        `/api/v2/authcheck`,
        params
      );
      return response.data;
    });
    __publicField$1(this, "getApiKey", async () => {
      const response = await this.axios.post(
        "/api/v2/users/me/keys"
      );
      return response.data;
    });
    __publicField$1(this, "getTokens", async (params) => {
      const response = await this.axios.get(
        `/api/v2/users/me/keys/tokens`,
        { params }
      );
      return response.data;
    });
    __publicField$1(this, "deleteToken", async (keyId) => {
      await this.axios.delete(`/api/v2/users/me/keys/${keyId}`);
    });
    __publicField$1(this, "createToken", async (params) => {
      const response = await this.axios.post(
        `/api/v2/users/me/keys/tokens`,
        params
      );
      return response.data;
    });
    __publicField$1(this, "getTokenConfig", async () => {
      const response = await this.axios.get(
        "/api/v2/users/me/keys/tokens/tokenconfig"
      );
      return response.data;
    });
    __publicField$1(this, "getUsers", async (options, signal) => {
      const url = getURLWithSearchParams("/api/v2/users", options);
      const response = await this.axios.get(
        url.toString(),
        { signal }
      );
      return response.data;
    });
    __publicField$1(this, "getOrganization", async (organizationId) => {
      const response = await this.axios.get(
        `/api/v2/organizations/${organizationId}`
      );
      return response.data;
    });
    __publicField$1(this, "getOrganizations", async () => {
      const response = await this.axios.get(
        "/api/v2/users/me/organizations"
      );
      return response.data;
    });
    __publicField$1(this, "getTemplate", async (templateId) => {
      const response = await this.axios.get(
        `/api/v2/templates/${templateId}`
      );
      return response.data;
    });
    __publicField$1(this, "getTemplates", async (organizationId, options) => {
      const params = {};
      if ((options == null ? void 0 : options.deprecated) !== void 0) {
        params.deprecated = String(options.deprecated);
      }
      const response = await this.axios.get(
        `/api/v2/organizations/${organizationId}/templates`,
        { params }
      );
      return response.data;
    });
    __publicField$1(this, "getTemplateByName", async (organizationId, name) => {
      const response = await this.axios.get(
        `/api/v2/organizations/${organizationId}/templates/${name}`
      );
      return response.data;
    });
    __publicField$1(this, "getTemplateVersion", async (versionId) => {
      const response = await this.axios.get(
        `/api/v2/templateversions/${versionId}`
      );
      return response.data;
    });
    __publicField$1(this, "getTemplateVersionResources", async (versionId) => {
      const response = await this.axios.get(
        `/api/v2/templateversions/${versionId}/resources`
      );
      return response.data;
    });
    __publicField$1(this, "getTemplateVersionVariables", async (versionId) => {
      const response = await this.axios.get(
        `/api/v2/templateversions/${versionId}/variables`
      );
      return response.data;
    });
    __publicField$1(this, "getTemplateVersions", async (templateId) => {
      const response = await this.axios.get(
        `/api/v2/templates/${templateId}/versions`
      );
      return response.data;
    });
    __publicField$1(this, "getTemplateVersionByName", async (organizationId, templateName, versionName) => {
      const response = await this.axios.get(
        `/api/v2/organizations/${organizationId}/templates/${templateName}/versions/${versionName}`
      );
      return response.data;
    });
    __publicField$1(this, "getPreviousTemplateVersionByName", async (organizationId, templateName, versionName) => {
      try {
        const response = await this.axios.get(
          `/api/v2/organizations/${organizationId}/templates/${templateName}/versions/${versionName}/previous`
        );
        return response.data;
      } catch (error) {
        const is404 = isAxiosError(error) && error.response && error.response.status === 404;
        if (is404) {
          return void 0;
        }
        throw error;
      }
    });
    __publicField$1(this, "createTemplateVersion", async (organizationId, data) => {
      const response = await this.axios.post(
        `/api/v2/organizations/${organizationId}/templateversions`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "getTemplateVersionExternalAuth", async (versionId) => {
      const response = await this.axios.get(
        `/api/v2/templateversions/${versionId}/external-auth`
      );
      return response.data;
    });
    __publicField$1(this, "getTemplateVersionRichParameters", async (versionId) => {
      const response = await this.axios.get(
        `/api/v2/templateversions/${versionId}/rich-parameters`
      );
      return response.data;
    });
    __publicField$1(this, "createTemplate", async (organizationId, data) => {
      const response = await this.axios.post(
        `/api/v2/organizations/${organizationId}/templates`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "updateActiveTemplateVersion", async (templateId, data) => {
      const response = await this.axios.patch(
        `/api/v2/templates/${templateId}/versions`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "patchTemplateVersion", async (templateVersionId, data) => {
      const response = await this.axios.patch(
        `/api/v2/templateversions/${templateVersionId}`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "archiveTemplateVersion", async (templateVersionId) => {
      const response = await this.axios.post(
        `/api/v2/templateversions/${templateVersionId}/archive`
      );
      return response.data;
    });
    __publicField$1(this, "unarchiveTemplateVersion", async (templateVersionId) => {
      const response = await this.axios.post(
        `/api/v2/templateversions/${templateVersionId}/unarchive`
      );
      return response.data;
    });
    __publicField$1(this, "updateTemplateMeta", async (templateId, data) => {
      const response = await this.axios.patch(
        `/api/v2/templates/${templateId}`,
        data
      );
      if (response.status === 304) {
        return null;
      }
      return response.data;
    });
    __publicField$1(this, "deleteTemplate", async (templateId) => {
      const response = await this.axios.delete(
        `/api/v2/templates/${templateId}`
      );
      return response.data;
    });
    __publicField$1(this, "getWorkspace", async (workspaceId, params) => {
      const response = await this.axios.get(
        `/api/v2/workspaces/${workspaceId}`,
        { params }
      );
      return response.data;
    });
    __publicField$1(this, "getWorkspaces", async (options) => {
      const url = getURLWithSearchParams("/api/v2/workspaces", options);
      const response = await this.axios.get(url);
      return response.data;
    });
    __publicField$1(this, "getWorkspaceByOwnerAndName", async (username = "me", workspaceName, params) => {
      const response = await this.axios.get(
        `/api/v2/users/${username}/workspace/${workspaceName}`,
        { params }
      );
      return response.data;
    });
    __publicField$1(this, "getWorkspaceBuildByNumber", async (username = "me", workspaceName, buildNumber) => {
      const response = await this.axios.get(
        `/api/v2/users/${username}/workspace/${workspaceName}/builds/${buildNumber}`
      );
      return response.data;
    });
    __publicField$1(this, "waitForBuild", (build) => {
      return new Promise((res, reject) => {
        void (async () => {
          let latestJobInfo = void 0;
          while (
            // eslint-disable-next-line no-loop-func -- Not great, but should be harmless
            !["succeeded", "canceled"].some(
              (status) => latestJobInfo == null ? void 0 : latestJobInfo.status.includes(status)
            )
          ) {
            const { job } = await this.getWorkspaceBuildByNumber(
              build.workspace_owner_name,
              build.workspace_name,
              build.build_number
            );
            latestJobInfo = job;
            if (latestJobInfo.status === "failed") {
              return reject(latestJobInfo);
            }
            await delay(1e3);
          }
          return res(latestJobInfo);
        })();
      });
    });
    __publicField$1(this, "postWorkspaceBuild", async (workspaceId, data) => {
      const response = await this.axios.post(
        `/api/v2/workspaces/${workspaceId}/builds`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "startWorkspace", (workspaceId, templateVersionId, logLevel, buildParameters) => {
      return this.postWorkspaceBuild(workspaceId, {
        transition: "start",
        template_version_id: templateVersionId,
        log_level: logLevel,
        rich_parameter_values: buildParameters
      });
    });
    __publicField$1(this, "stopWorkspace", (workspaceId, logLevel) => {
      return this.postWorkspaceBuild(workspaceId, {
        transition: "stop",
        log_level: logLevel
      });
    });
    __publicField$1(this, "deleteWorkspace", (workspaceId, options) => {
      return this.postWorkspaceBuild(workspaceId, {
        transition: "delete",
        ...options
      });
    });
    __publicField$1(this, "cancelWorkspaceBuild", async (workspaceBuildId) => {
      const response = await this.axios.patch(
        `/api/v2/workspacebuilds/${workspaceBuildId}/cancel`
      );
      return response.data;
    });
    __publicField$1(this, "updateWorkspaceDormancy", async (workspaceId, dormant) => {
      const data = { dormant };
      const response = await this.axios.put(
        `/api/v2/workspaces/${workspaceId}/dormant`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "updateWorkspaceAutomaticUpdates", async (workspaceId, automaticUpdates) => {
      const req = {
        automatic_updates: automaticUpdates
      };
      const response = await this.axios.put(
        `/api/v2/workspaces/${workspaceId}/autoupdates`,
        req
      );
      return response.data;
    });
    __publicField$1(this, "restartWorkspace", async ({
      workspace,
      buildParameters
    }) => {
      const stopBuild = await this.stopWorkspace(workspace.id);
      const awaitedStopBuild = await this.waitForBuild(stopBuild);
      if ((awaitedStopBuild == null ? void 0 : awaitedStopBuild.status) === "canceled") {
        return;
      }
      const startBuild = await this.startWorkspace(
        workspace.id,
        workspace.latest_build.template_version_id,
        void 0,
        buildParameters
      );
      await this.waitForBuild(startBuild);
    });
    __publicField$1(this, "cancelTemplateVersionBuild", async (templateVersionId) => {
      const response = await this.axios.patch(
        `/api/v2/templateversions/${templateVersionId}/cancel`
      );
      return response.data;
    });
    __publicField$1(this, "createUser", async (user) => {
      const response = await this.axios.post(
        "/api/v2/users",
        user
      );
      return response.data;
    });
    __publicField$1(this, "createWorkspace", async (organizationId, userId = "me", workspace) => {
      const response = await this.axios.post(
        `/api/v2/organizations/${organizationId}/members/${userId}/workspaces`,
        workspace
      );
      return response.data;
    });
    __publicField$1(this, "patchWorkspace", async (workspaceId, data) => {
      await this.axios.patch(`/api/v2/workspaces/${workspaceId}`, data);
    });
    __publicField$1(this, "getBuildInfo", async () => {
      const response = await this.axios.get("/api/v2/buildinfo");
      return response.data;
    });
    __publicField$1(this, "getUpdateCheck", async () => {
      const response = await this.axios.get("/api/v2/updatecheck");
      return response.data;
    });
    __publicField$1(this, "putWorkspaceAutostart", async (workspaceID, autostart) => {
      const payload = JSON.stringify(autostart);
      await this.axios.put(
        `/api/v2/workspaces/${workspaceID}/autostart`,
        payload,
        { headers: { ...BASE_CONTENT_TYPE_JSON } }
      );
    });
    __publicField$1(this, "putWorkspaceAutostop", async (workspaceID, ttl) => {
      const payload = JSON.stringify(ttl);
      await this.axios.put(`/api/v2/workspaces/${workspaceID}/ttl`, payload, {
        headers: { ...BASE_CONTENT_TYPE_JSON }
      });
    });
    __publicField$1(this, "updateProfile", async (userId, data) => {
      const response = await this.axios.put(
        `/api/v2/users/${userId}/profile`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "updateAppearanceSettings", async (userId, data) => {
      const response = await this.axios.put(
        `/api/v2/users/${userId}/appearance`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "getUserQuietHoursSchedule", async (userId) => {
      const response = await this.axios.get(
        `/api/v2/users/${userId}/quiet-hours`
      );
      return response.data;
    });
    __publicField$1(this, "updateUserQuietHoursSchedule", async (userId, data) => {
      const response = await this.axios.put(
        `/api/v2/users/${userId}/quiet-hours`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "activateUser", async (userId) => {
      const response = await this.axios.put(
        `/api/v2/users/${userId}/status/activate`
      );
      return response.data;
    });
    __publicField$1(this, "suspendUser", async (userId) => {
      const response = await this.axios.put(
        `/api/v2/users/${userId}/status/suspend`
      );
      return response.data;
    });
    __publicField$1(this, "deleteUser", async (userId) => {
      await this.axios.delete(`/api/v2/users/${userId}`);
    });
    // API definition:
    // https://github.com/coder/coder/blob/db665e7261f3c24a272ccec48233a3e276878239/coderd/users.go#L33-L53
    __publicField$1(this, "hasFirstUser", async () => {
      var _a;
      try {
        await this.axios.get("/api/v2/users/first");
        return true;
      } catch (error) {
        if (isAxiosError(error) && ((_a = error.response) == null ? void 0 : _a.status) === 404) {
          return false;
        }
        throw error;
      }
    });
    __publicField$1(this, "createFirstUser", async (req) => {
      const response = await this.axios.post(`/api/v2/users/first`, req);
      return response.data;
    });
    __publicField$1(this, "updateUserPassword", async (userId, updatePassword) => {
      await this.axios.put(`/api/v2/users/${userId}/password`, updatePassword);
    });
    __publicField$1(this, "getRoles", async () => {
      const response = await this.axios.get(
        `/api/v2/users/roles`
      );
      return response.data;
    });
    __publicField$1(this, "updateUserRoles", async (roles, userId) => {
      const response = await this.axios.put(
        `/api/v2/users/${userId}/roles`,
        { roles }
      );
      return response.data;
    });
    __publicField$1(this, "getUserSSHKey", async (userId = "me") => {
      const response = await this.axios.get(
        `/api/v2/users/${userId}/gitsshkey`
      );
      return response.data;
    });
    __publicField$1(this, "regenerateUserSSHKey", async (userId = "me") => {
      const response = await this.axios.put(
        `/api/v2/users/${userId}/gitsshkey`
      );
      return response.data;
    });
    __publicField$1(this, "getWorkspaceBuilds", async (workspaceId, req) => {
      const response = await this.axios.get(
        getURLWithSearchParams(`/api/v2/workspaces/${workspaceId}/builds`, req)
      );
      return response.data;
    });
    __publicField$1(this, "getWorkspaceBuildLogs", async (buildId, before) => {
      const response = await this.axios.get(
        `/api/v2/workspacebuilds/${buildId}/logs?before=${before.getTime()}`
      );
      return response.data;
    });
    __publicField$1(this, "getWorkspaceAgentLogs", async (agentID) => {
      const response = await this.axios.get(
        `/api/v2/workspaceagents/${agentID}/logs`
      );
      return response.data;
    });
    __publicField$1(this, "putWorkspaceExtension", async (workspaceId, newDeadline) => {
      await this.axios.put(`/api/v2/workspaces/${workspaceId}/extend`, {
        deadline: newDeadline
      });
    });
    __publicField$1(this, "refreshEntitlements", async () => {
      await this.axios.post("/api/v2/licenses/refresh-entitlements");
    });
    __publicField$1(this, "getEntitlements", async () => {
      var _a;
      try {
        const response = await this.axios.get(
          "/api/v2/entitlements"
        );
        return response.data;
      } catch (ex) {
        if (isAxiosError(ex) && ((_a = ex.response) == null ? void 0 : _a.status) === 404) {
          return {
            errors: [],
            features: withDefaultFeatures({}),
            has_license: false,
            require_telemetry: false,
            trial: false,
            warnings: [],
            refreshed_at: ""
          };
        }
        throw ex;
      }
    });
    __publicField$1(this, "getExperiments", async () => {
      var _a;
      try {
        const response = await this.axios.get(
          "/api/v2/experiments"
        );
        return response.data;
      } catch (error) {
        if (isAxiosError(error) && ((_a = error.response) == null ? void 0 : _a.status) === 404) {
          return [];
        }
        throw error;
      }
    });
    __publicField$1(this, "getAvailableExperiments", async () => {
      var _a;
      try {
        const response = await this.axios.get("/api/v2/experiments/available");
        return response.data;
      } catch (error) {
        if (isAxiosError(error) && ((_a = error.response) == null ? void 0 : _a.status) === 404) {
          return { safe: [] };
        }
        throw error;
      }
    });
    __publicField$1(this, "getExternalAuthProvider", async (provider) => {
      const res = await this.axios.get(`/api/v2/external-auth/${provider}`);
      return res.data;
    });
    __publicField$1(this, "getExternalAuthDevice", async (provider) => {
      const resp = await this.axios.get(
        `/api/v2/external-auth/${provider}/device`
      );
      return resp.data;
    });
    __publicField$1(this, "exchangeExternalAuthDevice", async (provider, req) => {
      const resp = await this.axios.post(
        `/api/v2/external-auth/${provider}/device`,
        req
      );
      return resp.data;
    });
    __publicField$1(this, "getUserExternalAuthProviders", async () => {
      const resp = await this.axios.get(`/api/v2/external-auth`);
      return resp.data;
    });
    __publicField$1(this, "unlinkExternalAuthProvider", async (provider) => {
      const resp = await this.axios.delete(`/api/v2/external-auth/${provider}`);
      return resp.data;
    });
    __publicField$1(this, "getOAuth2ProviderApps", async (filter) => {
      const params = (filter == null ? void 0 : filter.user_id) ? new URLSearchParams({ user_id: filter.user_id }).toString() : "";
      const resp = await this.axios.get(`/api/v2/oauth2-provider/apps?${params}`);
      return resp.data;
    });
    __publicField$1(this, "getOAuth2ProviderApp", async (id) => {
      const resp = await this.axios.get(`/api/v2/oauth2-provider/apps/${id}`);
      return resp.data;
    });
    __publicField$1(this, "postOAuth2ProviderApp", async (data) => {
      const response = await this.axios.post(
        `/api/v2/oauth2-provider/apps`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "putOAuth2ProviderApp", async (id, data) => {
      const response = await this.axios.put(
        `/api/v2/oauth2-provider/apps/${id}`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "deleteOAuth2ProviderApp", async (id) => {
      await this.axios.delete(`/api/v2/oauth2-provider/apps/${id}`);
    });
    __publicField$1(this, "getOAuth2ProviderAppSecrets", async (id) => {
      const resp = await this.axios.get(
        `/api/v2/oauth2-provider/apps/${id}/secrets`
      );
      return resp.data;
    });
    __publicField$1(this, "postOAuth2ProviderAppSecret", async (id) => {
      const resp = await this.axios.post(
        `/api/v2/oauth2-provider/apps/${id}/secrets`
      );
      return resp.data;
    });
    __publicField$1(this, "deleteOAuth2ProviderAppSecret", async (appId, secretId) => {
      await this.axios.delete(
        `/api/v2/oauth2-provider/apps/${appId}/secrets/${secretId}`
      );
    });
    __publicField$1(this, "revokeOAuth2ProviderApp", async (appId) => {
      await this.axios.delete(`/oauth2/tokens?client_id=${appId}`);
    });
    __publicField$1(this, "getAuditLogs", async (options) => {
      const url = getURLWithSearchParams("/api/v2/audit", options);
      const response = await this.axios.get(url);
      return response.data;
    });
    __publicField$1(this, "getTemplateDAUs", async (templateId) => {
      const response = await this.axios.get(
        `/api/v2/templates/${templateId}/daus`
      );
      return response.data;
    });
    __publicField$1(this, "getDeploymentDAUs", async (offset = Math.trunc((/* @__PURE__ */ new Date()).getTimezoneOffset() / 60)) => {
      const response = await this.axios.get(
        `/api/v2/insights/daus?tz_offset=${offset}`
      );
      return response.data;
    });
    __publicField$1(this, "getTemplateACLAvailable", async (templateId, options) => {
      const url = getURLWithSearchParams(
        `/api/v2/templates/${templateId}/acl/available`,
        options
      ).toString();
      const response = await this.axios.get(url);
      return response.data;
    });
    __publicField$1(this, "getTemplateACL", async (templateId) => {
      const response = await this.axios.get(
        `/api/v2/templates/${templateId}/acl`
      );
      return response.data;
    });
    __publicField$1(this, "updateTemplateACL", async (templateId, data) => {
      const response = await this.axios.patch(
        `/api/v2/templates/${templateId}/acl`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "getApplicationsHost", async () => {
      const response = await this.axios.get(`/api/v2/applications/host`);
      return response.data;
    });
    __publicField$1(this, "getGroups", async (organizationId) => {
      const response = await this.axios.get(
        `/api/v2/organizations/${organizationId}/groups`
      );
      return response.data;
    });
    __publicField$1(this, "createGroup", async (organizationId, data) => {
      const response = await this.axios.post(
        `/api/v2/organizations/${organizationId}/groups`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "getGroup", async (groupId) => {
      const response = await this.axios.get(`/api/v2/groups/${groupId}`);
      return response.data;
    });
    __publicField$1(this, "patchGroup", async (groupId, data) => {
      const response = await this.axios.patch(`/api/v2/groups/${groupId}`, data);
      return response.data;
    });
    __publicField$1(this, "addMember", async (groupId, userId) => {
      return this.patchGroup(groupId, {
        name: "",
        add_users: [userId],
        remove_users: []
      });
    });
    __publicField$1(this, "removeMember", async (groupId, userId) => {
      return this.patchGroup(groupId, {
        name: "",
        display_name: "",
        add_users: [],
        remove_users: [userId]
      });
    });
    __publicField$1(this, "deleteGroup", async (groupId) => {
      await this.axios.delete(`/api/v2/groups/${groupId}`);
    });
    __publicField$1(this, "getWorkspaceQuota", async (username) => {
      const response = await this.axios.get(
        `/api/v2/workspace-quota/${encodeURIComponent(username)}`
      );
      return response.data;
    });
    __publicField$1(this, "getAgentListeningPorts", async (agentID) => {
      const response = await this.axios.get(
        `/api/v2/workspaceagents/${agentID}/listening-ports`
      );
      return response.data;
    });
    __publicField$1(this, "getWorkspaceAgentSharedPorts", async (workspaceID) => {
      const response = await this.axios.get(
        `/api/v2/workspaces/${workspaceID}/port-share`
      );
      return response.data;
    });
    __publicField$1(this, "upsertWorkspaceAgentSharedPort", async (workspaceID, req) => {
      const response = await this.axios.post(
        `/api/v2/workspaces/${workspaceID}/port-share`,
        req
      );
      return response.data;
    });
    __publicField$1(this, "deleteWorkspaceAgentSharedPort", async (workspaceID, req) => {
      const response = await this.axios.delete(
        `/api/v2/workspaces/${workspaceID}/port-share`,
        { data: req }
      );
      return response.data;
    });
    // getDeploymentSSHConfig is used by the VSCode-Extension.
    __publicField$1(this, "getDeploymentSSHConfig", async () => {
      const response = await this.axios.get(`/api/v2/deployment/ssh`);
      return response.data;
    });
    __publicField$1(this, "getDeploymentConfig", async () => {
      const response = await this.axios.get(`/api/v2/deployment/config`);
      return response.data;
    });
    __publicField$1(this, "getDeploymentStats", async () => {
      const response = await this.axios.get(`/api/v2/deployment/stats`);
      return response.data;
    });
    __publicField$1(this, "getReplicas", async () => {
      const response = await this.axios.get(`/api/v2/replicas`);
      return response.data;
    });
    __publicField$1(this, "getFile", async (fileId) => {
      const response = await this.axios.get(
        `/api/v2/files/${fileId}`,
        { responseType: "arraybuffer" }
      );
      return response.data;
    });
    __publicField$1(this, "getWorkspaceProxyRegions", async () => {
      const response = await this.axios.get(`/api/v2/regions`);
      return response.data;
    });
    __publicField$1(this, "getWorkspaceProxies", async () => {
      const response = await this.axios.get(`/api/v2/workspaceproxies`);
      return response.data;
    });
    __publicField$1(this, "createWorkspaceProxy", async (b) => {
      const response = await this.axios.post(`/api/v2/workspaceproxies`, b);
      return response.data;
    });
    __publicField$1(this, "getAppearance", async () => {
      var _a;
      try {
        const response = await this.axios.get(`/api/v2/appearance`);
        return response.data || {};
      } catch (ex) {
        if (isAxiosError(ex) && ((_a = ex.response) == null ? void 0 : _a.status) === 404) {
          return {
            application_name: "",
            logo_url: "",
            notification_banners: [],
            service_banner: {
              enabled: false
            }
          };
        }
        throw ex;
      }
    });
    __publicField$1(this, "updateAppearance", async (b) => {
      const response = await this.axios.put(`/api/v2/appearance`, b);
      return response.data;
    });
    __publicField$1(this, "getTemplateExamples", async (organizationId) => {
      const response = await this.axios.get(
        `/api/v2/organizations/${organizationId}/templates/examples`
      );
      return response.data;
    });
    __publicField$1(this, "uploadFile", async (file) => {
      const response = await this.axios.post("/api/v2/files", file, {
        headers: { "Content-Type": "application/x-tar" }
      });
      return response.data;
    });
    __publicField$1(this, "getTemplateVersionLogs", async (versionId) => {
      const response = await this.axios.get(
        `/api/v2/templateversions/${versionId}/logs`
      );
      return response.data;
    });
    __publicField$1(this, "updateWorkspaceVersion", async (workspace) => {
      const template = await this.getTemplate(workspace.template_id);
      return this.startWorkspace(workspace.id, template.active_version_id);
    });
    __publicField$1(this, "getWorkspaceBuildParameters", async (workspaceBuildId) => {
      const response = await this.axios.get(
        `/api/v2/workspacebuilds/${workspaceBuildId}/parameters`
      );
      return response.data;
    });
    __publicField$1(this, "getLicenses", async () => {
      const response = await this.axios.get(`/api/v2/licenses`);
      return response.data;
    });
    __publicField$1(this, "createLicense", async (data) => {
      const response = await this.axios.post(`/api/v2/licenses`, data);
      return response.data;
    });
    __publicField$1(this, "removeLicense", async (licenseId) => {
      await this.axios.delete(`/api/v2/licenses/${licenseId}`);
    });
    /** Steps to change the workspace version
     * - Get the latest template to access the latest active version
     * - Get the current build parameters
     * - Get the template parameters
     * - Update the build parameters and check if there are missed parameters for
     *   the new version
     *   - If there are missing parameters raise an error
     * - Create a build with the version and updated build parameters
     */
    __publicField$1(this, "changeWorkspaceVersion", async (workspace, templateVersionId, newBuildParameters = []) => {
      const [currentBuildParameters, templateParameters] = await Promise.all([
        this.getWorkspaceBuildParameters(workspace.latest_build.id),
        this.getTemplateVersionRichParameters(templateVersionId)
      ]);
      const missingParameters = getMissingParameters(
        currentBuildParameters,
        newBuildParameters,
        templateParameters
      );
      if (missingParameters.length > 0) {
        throw new MissingBuildParameters(missingParameters, templateVersionId);
      }
      return this.postWorkspaceBuild(workspace.id, {
        transition: "start",
        template_version_id: templateVersionId,
        rich_parameter_values: newBuildParameters
      });
    });
    /** Steps to update the workspace
     * - Get the latest template to access the latest active version
     * - Get the current build parameters
     * - Get the template parameters
     * - Update the build parameters and check if there are missed parameters for
     *   the newest version
     *   - If there are missing parameters raise an error
     * - Create a build with the latest version and updated build parameters
     */
    __publicField$1(this, "updateWorkspace", async (workspace, newBuildParameters = []) => {
      const [template, oldBuildParameters] = await Promise.all([
        this.getTemplate(workspace.template_id),
        this.getWorkspaceBuildParameters(workspace.latest_build.id)
      ]);
      const activeVersionId = template.active_version_id;
      const templateParameters = await this.getTemplateVersionRichParameters(
        activeVersionId
      );
      const missingParameters = getMissingParameters(
        oldBuildParameters,
        newBuildParameters,
        templateParameters
      );
      if (missingParameters.length > 0) {
        throw new MissingBuildParameters(missingParameters, activeVersionId);
      }
      return this.postWorkspaceBuild(workspace.id, {
        transition: "start",
        template_version_id: activeVersionId,
        rich_parameter_values: newBuildParameters
      });
    });
    __publicField$1(this, "getWorkspaceResolveAutostart", async (workspaceId) => {
      const response = await this.axios.get(
        `/api/v2/workspaces/${workspaceId}/resolve-autostart`
      );
      return response.data;
    });
    __publicField$1(this, "issueReconnectingPTYSignedToken", async (params) => {
      const response = await this.axios.post(
        "/api/v2/applications/reconnecting-pty-signed-token",
        params
      );
      return response.data;
    });
    __publicField$1(this, "getWorkspaceParameters", async (workspace) => {
      const latestBuild = workspace.latest_build;
      const [templateVersionRichParameters, buildParameters] = await Promise.all([
        this.getTemplateVersionRichParameters(latestBuild.template_version_id),
        this.getWorkspaceBuildParameters(latestBuild.id)
      ]);
      return {
        templateVersionRichParameters,
        buildParameters
      };
    });
    __publicField$1(this, "getInsightsUserLatency", async (filters) => {
      const params = new URLSearchParams(filters);
      const response = await this.axios.get(
        `/api/v2/insights/user-latency?${params}`
      );
      return response.data;
    });
    __publicField$1(this, "getInsightsUserActivity", async (filters) => {
      const params = new URLSearchParams(filters);
      const response = await this.axios.get(
        `/api/v2/insights/user-activity?${params}`
      );
      return response.data;
    });
    __publicField$1(this, "getInsightsTemplate", async (params) => {
      const searchParams = new URLSearchParams(params);
      const response = await this.axios.get(
        `/api/v2/insights/templates?${searchParams}`
      );
      return response.data;
    });
    __publicField$1(this, "getHealth", async (force = false) => {
      const params = new URLSearchParams({ force: force.toString() });
      const response = await this.axios.get(
        `/api/v2/debug/health?${params}`
      );
      return response.data;
    });
    __publicField$1(this, "getHealthSettings", async () => {
      const res = await this.axios.get(
        `/api/v2/debug/health/settings`
      );
      return res.data;
    });
    __publicField$1(this, "updateHealthSettings", async (data) => {
      const response = await this.axios.put(
        `/api/v2/debug/health/settings`,
        data
      );
      return response.data;
    });
    __publicField$1(this, "putFavoriteWorkspace", async (workspaceID) => {
      await this.axios.put(`/api/v2/workspaces/${workspaceID}/favorite`);
    });
    __publicField$1(this, "deleteFavoriteWorkspace", async (workspaceID) => {
      await this.axios.delete(`/api/v2/workspaces/${workspaceID}/favorite`);
    });
    __publicField$1(this, "getJFrogXRayScan", async (options) => {
      var _a;
      const searchParams = new URLSearchParams({
        workspace_id: options.workspaceId,
        agent_id: options.agentId
      });
      try {
        const res = await this.axios.get(
          `/api/v2/integrations/jfrog/xray-scan?${searchParams}`
        );
        return res.data;
      } catch (error) {
        if (isAxiosError(error) && ((_a = error.response) == null ? void 0 : _a.status) === 404) {
          return null;
        }
        throw error;
      }
    });
  }
}
const csrfToken = "KNKvagCBEHZK7ihe2t7fj6VeJ0UyTDco1yVUJE8N06oNqxLu5Zx1vRxZbgfC0mJJgeGkVjgs08mgPbcWPBkZ1A==";
const tokenMetadataElement = typeof document !== "undefined" ? document.head.querySelector('meta[property="csrf-token"]') : null;
function getConfiguredAxiosInstance() {
  var _a;
  const instance = globalAxios.create();
  instance.defaults.validateStatus = (status) => {
    return status >= 200 && status < 300 || status === 304;
  };
  const metadataIsAvailable = tokenMetadataElement !== null && tokenMetadataElement.getAttribute("content") !== null;
  if (metadataIsAvailable) {
    if (process.env.NODE_ENV === "development") {
      instance.defaults.headers.common["X-CSRF-TOKEN"] = csrfToken;
      instance.defaults.headers.common["X-CSRF-TOKEN"] = csrfToken;
      tokenMetadataElement.setAttribute("content", csrfToken);
    } else {
      instance.defaults.headers.common["X-CSRF-TOKEN"] = (_a = tokenMetadataElement.getAttribute("content")) != null ? _a : "";
    }
  } else {
    if (process.env.JEST_WORKER_ID === void 0) {
      console.error("CSRF token not found");
    }
  }
  return instance;
}
class Api extends ApiMethods {
  constructor() {
    const scopedAxiosInstance = getConfiguredAxiosInstance();
    super(scopedAxiosInstance);
    // As with ApiMethods, all public methods should be defined with arrow
    // function syntax to ensure they can be passed around the React UI without
    // losing/detaching their `this` context!
    __publicField$1(this, "getCsrfToken", () => {
      return csrfToken;
    });
    __publicField$1(this, "setSessionToken", (token) => {
      this.axios.defaults.headers.common["Coder-Session-Token"] = token;
    });
    __publicField$1(this, "setHost", (host) => {
      this.axios.defaults.baseURL = host;
    });
    __publicField$1(this, "getAxiosInstance", () => {
      return this.axios;
    });
  }
}
new Api();

function createCoderApi() {
  const api = new Api();
  return api;
}

var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
const CODER_AUTH_HEADER_KEY = "Coder-Session-Token";
const DEFAULT_REQUEST_TIMEOUT_MS = 2e4;
const sharedCleanupAbortReason = new DOMException(
  "Coder Client instance has been manually cleaned up",
  "AbortError"
);
class CoderClientWrapper {
  constructor(inputs) {
    __publicField(this, "urlSync");
    __publicField(this, "identityApi");
    __publicField(this, "requestTimeoutMs");
    __publicField(this, "cleanupController");
    __publicField(this, "trackedEjectionIds");
    __publicField(this, "loadedSessionToken");
    __publicField(this, "api");
    /* ***************************************************************************
     * All public functions should be defined as arrow functions to ensure they
     * can be passed around React without risk of losing their `this` context
     ****************************************************************************/
    __publicField(this, "syncToken", async (newToken) => {
      var _a;
      const validationId = this.addRequestInterceptor((config) => {
        config.headers[CODER_AUTH_HEADER_KEY] = newToken;
        return config;
      });
      try {
        const dummyUser = await this.api.getAuthenticatedUser();
        assertValidUser(dummyUser);
        this.loadedSessionToken = newToken;
        return true;
      } catch (err) {
        const tokenIsInvalid = err instanceof AxiosError && ((_a = err.response) == null ? void 0 : _a.status) === 401;
        if (tokenIsInvalid) {
          return false;
        }
        throw err;
      } finally {
        this.removeRequestInterceptorById(validationId);
      }
    });
    const {
      initialToken,
      apis: { urlSync, identityApi },
      requestTimeoutMs = DEFAULT_REQUEST_TIMEOUT_MS
    } = inputs;
    this.urlSync = urlSync;
    this.identityApi = identityApi;
    this.loadedSessionToken = initialToken;
    this.requestTimeoutMs = requestTimeoutMs;
    this.cleanupController = new AbortController();
    this.trackedEjectionIds = /* @__PURE__ */ new Set();
    this.api = this.createBackstageCoderApi();
    this.addBaseRequestInterceptors();
  }
  addRequestInterceptor(requestInterceptor, errorInterceptor) {
    const axios = this.api.getAxiosInstance();
    const ejectionId = axios.interceptors.request.use(
      requestInterceptor,
      errorInterceptor
    );
    this.trackedEjectionIds.add(ejectionId);
    return ejectionId;
  }
  removeRequestInterceptorById(ejectionId) {
    const axios = this.api.getAxiosInstance();
    axios.interceptors.request.eject(ejectionId);
    if (!this.trackedEjectionIds.has(ejectionId)) {
      return false;
    }
    this.trackedEjectionIds.delete(ejectionId);
    return true;
  }
  addBaseRequestInterceptors() {
    const baseRequestInterceptor = async (config) => {
      const proxyApiEndpoint = await this.urlSync.getApiEndpoint();
      const bearerToken = (await this.identityApi.getCredentials()).token;
      config.baseURL = proxyApiEndpoint;
      config.signal = this.getTimeoutAbortSignal();
      if (config.headers[CODER_AUTH_HEADER_KEY] === void 0) {
        config.headers[CODER_AUTH_HEADER_KEY] = this.loadedSessionToken;
      }
      if (bearerToken) {
        config.headers.Authorization = `Bearer ${bearerToken}`;
      }
      return config;
    };
    const baseErrorInterceptor = (error) => {
      const errorIsFromCleanup = error instanceof DOMException && error.name === sharedCleanupAbortReason.name && error.message === sharedCleanupAbortReason.message;
      if (errorIsFromCleanup) {
        return void 0;
      }
      return error;
    };
    this.addRequestInterceptor(baseRequestInterceptor, baseErrorInterceptor);
  }
  createBackstageCoderApi() {
    const baseApi = createCoderApi();
    const getWorkspaces = async (request) => {
      const workspacesRes = await baseApi.getWorkspaces(request);
      const remapped = await this.remapWorkspaceIconUrls(
        workspacesRes.workspaces
      );
      return {
        ...workspacesRes,
        workspaces: remapped
      };
    };
    const getWorkspacesByRepo = async (request, config) => {
      if (config.repoUrl === void 0) {
        return { workspaces: [], count: 0 };
      }
      const stringUrl = config.repoUrl;
      const responses = await Promise.allSettled(
        config.repoUrlParamKeys.map((key) => {
          const patchedRequest = {
            ...request,
            q: appendParamToQuery(request.q, key, stringUrl)
          };
          return baseApi.getWorkspaces(patchedRequest);
        })
      );
      const uniqueWorkspaces = /* @__PURE__ */ new Map();
      for (const res of responses) {
        if (res.status === "rejected") {
          continue;
        }
        for (const workspace of res.value.workspaces) {
          uniqueWorkspaces.set(workspace.id, workspace);
        }
      }
      const serialized = [...uniqueWorkspaces.values()];
      return {
        workspaces: serialized,
        count: serialized.length
      };
    };
    return {
      ...baseApi,
      getWorkspaces,
      getWorkspacesByRepo
    };
  }
  /**
   * Creates a combined abort signal that will abort when the client is cleaned
   * up, but will also enforce request timeouts
   */
  getTimeoutAbortSignal() {
    const timeoutController = new AbortController();
    const timeoutId = window.setTimeout(() => {
      const reason = new DOMException("Signal timed out", "TimeoutException");
      timeoutController.abort(reason);
    }, this.requestTimeoutMs);
    const cleanupSignal = this.cleanupController.signal;
    cleanupSignal.addEventListener(
      "abort",
      () => {
        window.clearTimeout(timeoutId);
        timeoutController.abort(cleanupSignal.reason);
      },
      // Attaching the timeoutController signal here makes it so that if the
      // timeout resolves, this event listener will automatically be removed
      { signal: timeoutController.signal }
    );
    return timeoutController.signal;
  }
  async remapWorkspaceIconUrls(workspaces) {
    const assetsRoute = await this.urlSync.getAssetsEndpoint();
    return workspaces.map((ws) => {
      const templateIconUrl = ws.template_icon;
      if (!templateIconUrl.startsWith("/")) {
        return ws;
      }
      return {
        ...ws,
        template_icon: `${assetsRoute}${templateIconUrl}`
      };
    });
  }
}
function appendParamToQuery(query, key, value) {
  if (!key || !value) {
    return "";
  }
  const keyValuePair = `param:"${key}=${value}"`;
  if (!query) {
    return keyValuePair;
  }
  if (query.includes(keyValuePair)) {
    return query;
  }
  return `${query} ${keyValuePair}`;
}
function assertValidUser(value) {
  if (value === null || typeof value !== "object") {
    throw new Error("Returned JSON value is not an object");
  }
  const hasFields = "id" in value && typeof value.id === "string" && "username" in value && typeof value.username === "string";
  if (!hasFields) {
    throw new Error(
      "User object is missing expected fields for authentication request"
    );
  }
}
const coderClientWrapperApiRef = createApiRef({
  id: `${CODER_API_REF_ID_PREFIX}.coder-client`
});

let idCounter = 0;
function useIdPolyfill() {
  const [readonlyId] = useState(() => {
    idCounter++;
    return `:r${idCounter}:`;
  });
  return readonlyId;
}
const ReactWithNewerHooks = React;
const useId = typeof ReactWithNewerHooks.useId === "undefined" ? useIdPolyfill : ReactWithNewerHooks.useId;

var __accessCheck = (obj, member, msg) => {
  if (!member.has(obj))
    throw TypeError("Cannot " + msg);
};
var __privateGet = (obj, member, getter) => {
  __accessCheck(obj, member, "read from private field");
  return getter ? getter.call(obj) : member.get(obj);
};
var __privateAdd = (obj, member, value) => {
  if (member.has(obj))
    throw TypeError("Cannot add the same private member more than once");
  member instanceof WeakSet ? member.add(obj) : member.set(obj, value);
};
var __privateSet = (obj, member, value, setter) => {
  __accessCheck(obj, member, "write to private field");
  setter ? setter.call(obj, value) : member.set(obj, value);
  return value;
};
var _response;
const _BackstageHttpError = class _BackstageHttpError extends Error {
  constructor(errorMessage, response) {
    super(errorMessage);
    __privateAdd(this, _response, void 0);
    this.name = "HttpError";
    __privateSet(this, _response, response);
  }
  static isInstance(value) {
    return value instanceof _BackstageHttpError;
  }
  get status() {
    return __privateGet(this, _response).status;
  }
  get ok() {
    return __privateGet(this, _response).ok;
  }
  get contentType() {
    return __privateGet(this, _response).headers.get("content_type");
  }
};
_response = new WeakMap();
let BackstageHttpError = _BackstageHttpError;

const CODER_QUERY_KEY_PREFIX = "coder-backstage-plugin";
const sharedAuthQueryKey = [CODER_QUERY_KEY_PREFIX, "auth"];
const PENDING_REFETCH_INTERVAL_MS = 5e3;
const BACKGROUND_REFETCH_INTERVAL_MS = 6e4;
function getCoderWorkspacesRefetchInterval(workspaces2) {
  if (workspaces2 === void 0) {
    return false;
  }
  const areAnyWorkspacesPending = workspaces2.some((ws) => {
    if (ws.latest_build.status === "pending") {
      return true;
    }
    return ws.latest_build.resources.some((resource) => {
      var _a;
      const agents = resource.agents;
      return (_a = agents == null ? void 0 : agents.some((agent) => agent.status === "connecting")) != null ? _a : false;
    });
  });
  return areAnyWorkspacesPending ? PENDING_REFETCH_INTERVAL_MS : BACKGROUND_REFETCH_INTERVAL_MS;
}
function getSharedWorkspacesQueryKey(coderQuery) {
  return [CODER_QUERY_KEY_PREFIX, "workspaces", coderQuery];
}
function workspaces({
  auth,
  api,
  coderQuery
}) {
  const enabled = auth.isAuthenticated;
  return {
    queryKey: getSharedWorkspacesQueryKey(coderQuery),
    enabled,
    keepPreviousData: enabled && coderQuery !== "",
    refetchInterval: getCoderWorkspacesRefetchInterval,
    queryFn: async () => {
      const res = await api.getWorkspaces({
        q: coderQuery,
        limit: 0
      });
      return res.workspaces;
    }
  };
}
function workspacesByRepo({
  coderQuery,
  api,
  auth,
  workspacesConfig
}) {
  const enabled = auth.isAuthenticated && coderQuery.trim() !== "";
  return {
    queryKey: [...getSharedWorkspacesQueryKey(coderQuery), workspacesConfig],
    enabled,
    keepPreviousData: enabled,
    refetchInterval: getCoderWorkspacesRefetchInterval,
    queryFn: async () => {
      const request = { q: coderQuery, limit: 0 };
      const res = await api.getWorkspacesByRepo(request, workspacesConfig);
      return res.workspaces;
    }
  };
}

const useStyles$8 = makeStyles((theme) => ({
  root: {
    fill: theme.palette.text.primary,
    opacity: 1
  }
}));
const CoderLogo = ({
  className = "",
  ...delegatedProps
}) => {
  const styles = useStyles$8();
  return /* @__PURE__ */ React.createElement(
    "svg",
    {
      "aria-hidden": true,
      className: `${styles.root} ${className}`,
      viewBox: "0 0 68 49",
      width: "40",
      ...delegatedProps
    },
    /* @__PURE__ */ React.createElement("path", { d: "M66.3575 21.3584C65.0024 21.3584 64.099 20.5638 64.099 18.9328V9.5647C64.099 3.58419 61.6353 0.280273 55.2705 0.280273H52.314V6.59536H53.2174C55.7222 6.59536 56.913 7.97547 56.913 10.443V18.7237C56.913 22.3203 57.9807 23.7841 60.3212 24.5369C57.9807 25.2479 56.913 26.7534 56.913 30.3501C56.913 32.3994 56.913 34.4486 56.913 36.4979C56.913 38.2126 56.913 39.8855 56.4613 41.6002C56.0097 43.1894 55.2705 44.695 54.244 45.9914C53.6691 46.7442 53.0121 47.3716 52.2729 47.9571V48.7935H55.2295C61.5942 48.7935 64.058 45.4896 64.058 39.5091V30.141C64.058 28.4681 64.9203 27.7153 66.3164 27.7153H68V21.4003H66.3575V21.3584Z" }),
    /* @__PURE__ */ React.createElement("path", { d: "M46.2367 9.81532H37.1208C36.9155 9.81532 36.7512 9.64804 36.7512 9.43893V8.72796C36.7512 8.51885 36.9155 8.35156 37.1208 8.35156H46.2778C46.4831 8.35156 46.6473 8.51885 46.6473 8.72796V9.43893C46.6473 9.64804 46.442 9.81532 46.2367 9.81532Z" }),
    /* @__PURE__ */ React.createElement("path", { d: "M47.7971 18.8485H41.145C40.9396 18.8485 40.7754 18.6812 40.7754 18.4721V17.7612C40.7754 17.5521 40.9396 17.3848 41.145 17.3848H47.7971C48.0024 17.3848 48.1667 17.5521 48.1667 17.7612V18.4721C48.1667 18.6394 48.0024 18.8485 47.7971 18.8485Z" }),
    /* @__PURE__ */ React.createElement("path", { d: "M50.4251 14.3319H37.1208C36.9155 14.3319 36.7512 14.1646 36.7512 13.9555V13.2446C36.7512 13.0355 36.9155 12.8682 37.1208 12.8682H50.384C50.5894 12.8682 50.7536 13.0355 50.7536 13.2446V13.9555C50.7536 14.1228 50.6304 14.3319 50.4251 14.3319Z" }),
    /* @__PURE__ */ React.createElement("path", { d: "M26.5677 11.8649C27.4711 11.8649 28.3744 11.9485 29.2368 12.1577V10.443C29.2368 8.0173 30.4686 6.59536 32.9324 6.59536H33.8358V0.280273H30.8793C24.5145 0.280273 22.0508 3.58419 22.0508 9.5647V12.6595C23.488 12.1577 25.0073 11.8649 26.5677 11.8649Z" }),
    /* @__PURE__ */ React.createElement("path", { d: "M53.2174 34.6165C52.5603 29.3051 48.5362 24.872 43.3623 23.8683C41.9251 23.5755 40.4879 23.5337 39.0918 23.7847C39.0507 23.7847 39.0507 23.7428 39.0096 23.7428C36.7512 18.9333 31.9058 15.7549 26.6497 15.7549C21.3937 15.7549 16.5894 18.8497 14.2898 23.6592C14.2488 23.6592 14.2488 23.701 14.2077 23.701C12.7295 23.5337 11.2512 23.6174 9.77294 23.9938C4.68116 25.2484 0.821255 29.5979 0.123188 34.8674C0.0410628 35.4111 0 35.9548 0 36.4566C0 38.0459 1.06763 39.5096 2.62802 39.7187C4.55797 40.0115 6.24154 38.5059 6.20048 36.5821C6.20048 36.2894 6.20048 35.9548 6.24154 35.662C6.57004 32.9854 8.58212 30.7271 11.2101 30.0997C12.0314 29.8906 12.8526 29.8488 13.6328 29.9743C16.1377 30.3088 18.6014 29.0124 19.6691 26.754C20.4493 25.0811 21.6811 23.6174 23.3237 22.8228C25.1304 21.9445 27.1836 21.819 29.0724 22.4882C31.0435 23.1992 32.5217 24.7047 33.4251 26.5867C34.3695 28.4269 34.8212 29.7233 36.8333 29.9743C37.6546 30.0997 39.9541 30.0579 40.8164 30.0161C42.5 30.0161 44.1835 30.6016 45.3744 31.8144C46.1546 32.6509 46.7294 33.6964 46.9758 34.8674C47.3454 36.7494 46.8937 38.6314 45.785 40.0533C45.0048 41.057 43.9372 41.8098 42.7463 42.1444C42.1715 42.3117 41.5966 42.3535 41.0217 42.3535C40.6932 42.3535 40.2415 42.3535 39.7077 42.3535C38.0652 42.3535 34.5749 42.3535 31.9468 42.3535C30.1401 42.3535 28.7029 40.8897 28.7029 39.0496V32.86V26.7958C28.7029 26.294 28.2922 25.8757 27.7995 25.8757H26.5265C24.0217 25.9176 22.0096 28.7614 22.0096 31.7726C22.0096 34.7838 22.0096 42.7717 22.0096 42.7717C22.0096 46.0338 24.5966 48.6686 27.7995 48.6686C27.7995 48.6686 42.0483 48.6268 42.2536 48.6268C45.5386 48.2922 48.5773 46.5775 50.6304 43.9427C52.6835 41.3916 53.628 38.0459 53.2174 34.6165Z" })
  );
};

const useStyles$7 = makeStyles(() => ({
  root: {
    display: "block",
    maxWidth: "fit-content"
  }
}));
function UnlinkAccountButton({
  className,
  onClick,
  type = "button",
  ...delegatedProps
}) {
  const styles = useStyles$7();
  const { unlinkToken } = useInternalCoderAuth();
  return /* @__PURE__ */ React.createElement(
    LinkButton,
    {
      disableRipple: true,
      to: "",
      component: "button",
      type,
      color: "primary",
      variant: "contained",
      className: `${styles.root} ${className}`,
      onClick: (event) => {
        unlinkToken();
        onClick == null ? void 0 : onClick(event);
      },
      ...delegatedProps
    },
    "Unlink Coder account"
  );
}

const useStyles$6 = makeStyles((theme) => ({
  root: {
    display: "flex",
    flexFlow: "column nowrap",
    alignItems: "center",
    maxWidth: "30em",
    marginLeft: "auto",
    marginRight: "auto",
    rowGap: theme.spacing(2)
  },
  button: {
    maxWidth: "fit-content",
    marginLeft: "auto",
    marginRight: "auto"
  },
  coderLogo: {
    display: "block",
    width: "fit-content",
    marginLeft: "auto",
    marginRight: "auto"
  }
}));
const CoderAuthDistrustedForm = () => {
  const styles = useStyles$6();
  return /* @__PURE__ */ React.createElement("div", { className: styles.root }, /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(CoderLogo, { className: styles.coderLogo }), /* @__PURE__ */ React.createElement("p", null, "Unable to verify token authenticity. Please check your internet connection, or try unlinking the token.")), /* @__PURE__ */ React.createElement(UnlinkAccountButton, { className: styles.button }));
};

const visuallyHiddenStyles = {
  display: "inline-block",
  position: "absolute",
  overflow: "hidden",
  clip: "rect(0 0 0 0)",
  height: 1,
  width: 1,
  margin: -1,
  padding: 0,
  border: 0
};
const VisuallyHidden = ({
  children,
  ...delegatedProps
}) => {
  const [forceShow, setForceShow] = useState(false);
  useEffect(() => {
    if (process.env.NODE_ENV === "production") {
      return void 0;
    }
    const handleKeyDown = (event) => {
      if (event.shiftKey && event.key === "Alt") {
        setForceShow(true);
      }
    };
    const handleKeyUp = (event) => {
      if (event.key === "Alt") {
        setForceShow(false);
      }
    };
    window.addEventListener("keydown", handleKeyDown);
    window.addEventListener("keyup", handleKeyUp);
    return () => {
      window.removeEventListener("keydown", handleKeyDown);
      window.removeEventListener("keyup", handleKeyUp);
    };
  }, []);
  if (forceShow) {
    return /* @__PURE__ */ React.createElement(React.Fragment, null, children);
  }
  return /* @__PURE__ */ React.createElement("span", { style: visuallyHiddenStyles, ...delegatedProps }, children);
};

const MAX_DOTS = 3;
const dotRange = new Array(MAX_DOTS).fill(null).map((_, i) => i + 1);
const useStyles$5 = makeStyles((theme) => ({
  root: {
    display: "flex",
    flexFlow: "column nowrap",
    alignItems: "center"
  },
  text: {
    lineHeight: theme.typography.body1.lineHeight,
    paddingLeft: theme.spacing(1)
  },
  coderLogo: {
    display: "block",
    width: "fit-content",
    marginLeft: "auto",
    marginRight: "auto"
  }
}));
const CoderAuthLoadingState = () => {
  const [visibleDots, setVisibleDots] = useState(0);
  const styles = useStyles$5();
  useEffect(() => {
    const intervalId = window.setInterval(() => {
      setVisibleDots((current) => (current + 1) % (MAX_DOTS + 1));
    }, 1e3);
    return () => window.clearInterval(intervalId);
  }, []);
  return /* @__PURE__ */ React.createElement("div", { className: styles.root }, /* @__PURE__ */ React.createElement(CoderLogo, { className: styles.coderLogo }), /* @__PURE__ */ React.createElement("p", { className: styles.text }, "Loading", /* @__PURE__ */ React.createElement(VisuallyHidden, null, "\u2026"), dotRange.map((dotPosition) => /* @__PURE__ */ React.createElement(
    "span",
    {
      key: dotPosition,
      style: { opacity: visibleDots >= dotPosition ? 1 : 0 },
      "aria-hidden": true
    },
    "."
  ))));
};

const useStyles$4 = makeStyles((theme) => ({
  formContainer: {
    maxWidth: "30em",
    marginLeft: "auto",
    marginRight: "auto"
  },
  authInputFieldset: {
    display: "flex",
    flexFlow: "column nowrap",
    rowGap: theme.spacing(2),
    margin: `${theme.spacing(-0.5)} 0 0 0`,
    border: "none",
    padding: 0
  },
  coderLogo: {
    display: "block",
    width: "fit-content",
    marginLeft: "auto",
    marginRight: "auto"
  },
  authButton: {
    display: "block",
    width: "fit-content",
    marginLeft: "auto",
    marginRight: "auto"
  }
}));
const CoderAuthInputForm = () => {
  const hookId = useId();
  const styles = useStyles$4();
  const appConfig = useCoderAppConfig();
  const { status, registerNewToken } = useInternalCoderAuth();
  const onSubmit = (event) => {
    event.preventDefault();
    const formData = Object.fromEntries(new FormData(event.currentTarget));
    const newToken = typeof formData.authToken === "string" ? formData.authToken : "";
    registerNewToken(newToken);
  };
  const formHeaderId = `${hookId}-form-header`;
  const legendId = `${hookId}-legend`;
  const authTokenInputId = `${hookId}-auth-token`;
  const warningBannerId = `${hookId}-warning-banner`;
  return /* @__PURE__ */ React.createElement(
    "form",
    {
      "aria-labelledby": formHeaderId,
      className: styles.formContainer,
      onSubmit
    },
    /* @__PURE__ */ React.createElement("h3", { hidden: true, id: formHeaderId }, "Authenticate with Coder"),
    /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(CoderLogo, { className: styles.coderLogo }), /* @__PURE__ */ React.createElement("p", null, "Link your Coder account to create remote workspaces. Please enter a new token from your", " ", /* @__PURE__ */ React.createElement(
      Link,
      {
        to: `${appConfig.deployment.accessUrl}/cli-auth`,
        target: "_blank"
      },
      "Coder deployment's token page",
      /* @__PURE__ */ React.createElement(VisuallyHidden, null, " (link opens in new tab)")
    ), ".")),
    /* @__PURE__ */ React.createElement("fieldset", { className: styles.authInputFieldset, "aria-labelledby": legendId }, /* @__PURE__ */ React.createElement("legend", { hidden: true, id: legendId }, "Auth input"), /* @__PURE__ */ React.createElement(
      TextField,
      {
        label: "Auth token",
        InputLabelProps: { htmlFor: authTokenInputId },
        InputProps: { id: authTokenInputId },
        required: true,
        name: "authToken",
        type: "password",
        defaultValue: "",
        "aria-errormessage": warningBannerId,
        style: { width: "100%" }
      }
    ), /* @__PURE__ */ React.createElement(
      LinkButton,
      {
        disableRipple: true,
        to: "",
        component: "button",
        type: "submit",
        color: "primary",
        variant: "contained",
        className: styles.authButton
      },
      "Authenticate"
    )),
    (status === "invalid" || status === "authenticating") && /* @__PURE__ */ React.createElement(InvalidStatusNotifier, { authStatus: status, bannerId: warningBannerId })
  );
};
const useInvalidStatusStyles = makeStyles((theme) => ({
  warningBannerSpacer: {
    paddingTop: theme.spacing(2)
  },
  warningBanner: {
    display: "flex",
    flexFlow: "row nowrap",
    alignItems: "center",
    color: theme.palette.text.primary,
    backgroundColor: theme.palette.background.default,
    borderRadius: theme.shape.borderRadius,
    border: `1.5px solid ${theme.palette.background.default}`,
    padding: 0
  },
  errorContent: {
    display: "flex",
    flexFlow: "row nowrap",
    alignItems: "center",
    columnGap: theme.spacing(1),
    marginRight: "auto",
    paddingTop: theme.spacing(0.5),
    paddingBottom: theme.spacing(0.5),
    paddingLeft: theme.spacing(2),
    paddingRight: 0
  },
  icon: {
    fontSize: "16px"
  },
  syncIcon: {
    color: theme.palette.text.primary,
    opacity: 0.6
  },
  errorIcon: {
    color: theme.palette.error.main,
    fontSize: "16px"
  },
  dismissButton: {
    border: "none",
    alignSelf: "stretch",
    padding: `0 ${theme.spacing(1.5)}px 0 ${theme.spacing(2)}px`,
    color: theme.palette.text.primary,
    backgroundColor: "inherit",
    lineHeight: 1,
    cursor: "pointer",
    "&:hover": {
      backgroundColor: theme.palette.action.hover
    }
  },
  "@keyframes spin": {
    "100%": {
      transform: "rotate(360deg)"
    }
  }
}));
function InvalidStatusNotifier({ authStatus, bannerId }) {
  const [showNotification, setShowNotification] = useState(true);
  const styles = useInvalidStatusStyles();
  if (!showNotification) {
    return null;
  }
  return /* @__PURE__ */ React.createElement("div", { className: styles.warningBannerSpacer }, /* @__PURE__ */ React.createElement("div", { id: bannerId, className: styles.warningBanner }, /* @__PURE__ */ React.createElement("span", { className: styles.errorContent }, authStatus === "authenticating" && /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(
    SyncIcon,
    {
      className: `${styles.icon} ${styles.syncIcon}`,
      fontSize: "inherit"
    }
  ), "Authenticating\u2026"), authStatus === "invalid" && /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(
    ErrorIcon,
    {
      className: `${styles.icon} ${styles.errorIcon}`,
      fontSize: "inherit"
    }
  ), "Invalid token")), /* @__PURE__ */ React.createElement(
    "button",
    {
      className: styles.dismissButton,
      onClick: () => setShowNotification(false)
    },
    "Dismiss"
  )));
}

const useStyles$3 = makeStyles((theme) => ({
  root: {
    display: "flex",
    flexFlow: "column nowrap",
    alignItems: "center",
    rowGap: theme.spacing(1),
    maxWidth: "30em",
    marginLeft: "auto",
    marginRight: "auto",
    color: theme.palette.text.primary,
    fontSize: "1rem"
  },
  statusArea: {
    display: "flex",
    flexFlow: "column nowrap",
    alignItems: "center"
  },
  logo: {
    //
  },
  text: {
    textAlign: "center",
    lineHeight: "1rem"
  }
}));
function CoderAuthSuccessStatus() {
  const styles = useStyles$3();
  return /* @__PURE__ */ React.createElement("div", { className: styles.root }, /* @__PURE__ */ React.createElement("div", { className: styles.statusArea }, /* @__PURE__ */ React.createElement(CoderLogo, { className: styles.logo }), /* @__PURE__ */ React.createElement("p", { className: styles.text }, "You are fully authenticated with Coder!")), /* @__PURE__ */ React.createElement(UnlinkAccountButton, null));
}

const CoderAuthForm = ({ descriptionId }) => {
  const auth = useInternalCoderAuth();
  return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement("p", { id: descriptionId, hidden: true }, "Please authenticate with Coder to enable the Coder plugin for Backstage."), (() => {
    switch (auth.status) {
      case "initializing": {
        return /* @__PURE__ */ React.createElement(CoderAuthLoadingState, null);
      }
      case "distrusted":
      case "noInternetConnection":
      case "deploymentUnavailable": {
        return /* @__PURE__ */ React.createElement(CoderAuthDistrustedForm, null);
      }
      case "authenticating":
      case "invalid":
      case "tokenMissing": {
        return /* @__PURE__ */ React.createElement(CoderAuthInputForm, null);
      }
      case "authenticated":
      case "distrustedWithGracePeriod": {
        return /* @__PURE__ */ React.createElement(CoderAuthSuccessStatus, null);
      }
      default: {
        return assertExhaustion(auth);
      }
    }
  })());
};
function assertExhaustion(...inputs) {
  let inputsToLog;
  try {
    inputsToLog = JSON.stringify(inputs);
  } catch {
    inputsToLog = inputs;
  }
  throw new Error(
    `Not all possibilities for inputs (${inputsToLog}) have been exhausted`
  );
}

const useStyles$2 = makeStyles((theme) => ({
  trigger: {
    cursor: "pointer",
    color: theme.palette.primary.contrastText,
    backgroundColor: theme.palette.primary.main,
    width: "fit-content",
    border: "none",
    fontWeight: 600,
    borderRadius: theme.shape.borderRadius,
    transition: "10s color ease-in-out",
    padding: `${theme.spacing(1.5)}px ${theme.spacing(2)}px`,
    boxShadow: theme.shadows[10],
    "&:hover": {
      backgroundColor: theme.palette.primary.dark,
      boxShadow: theme.shadows[15]
    }
  },
  dialogContainer: {
    width: "100%",
    height: "100%",
    display: "flex",
    flexFlow: "column nowrap",
    justifyContent: "center",
    alignItems: "center"
  },
  dialogPaper: {
    width: "100%"
  },
  dialogTitle: {
    fontSize: "24px",
    borderBottom: `${theme.palette.divider} 1px solid`,
    padding: `${theme.spacing(1)}px ${theme.spacing(3)}px`
  },
  contentContainer: {
    padding: `${theme.spacing(6)}px ${theme.spacing(3)}px 0`
  },
  actionsRow: {
    display: "flex",
    flexFlow: "row nowrap",
    justifyContent: "center",
    padding: `${theme.spacing(1)}px ${theme.spacing(2)}px ${theme.spacing(
      6
    )}px`
  },
  closeButton: {
    letterSpacing: "0.05em",
    padding: `${theme.spacing(0.5)}px ${theme.spacing(1)}px`,
    color: theme.palette.primary.main,
    "&:hover": {
      textDecoration: "none"
    }
  }
}));
function CoderAuthFormDialog({
  children,
  onOpen,
  onClose,
  triggerClassName,
  open: outerIsOpen
}) {
  const hookId = useId();
  const styles = useStyles$2();
  const [innerIsOpen, setInnerIsOpen] = useState(false);
  const handleClose = () => {
    setInnerIsOpen(false);
    onClose == null ? void 0 : onClose();
  };
  const isOpen = outerIsOpen != null ? outerIsOpen : innerIsOpen;
  const titleId = `${hookId}-dialog-title`;
  const descriptionId = `${hookId}-dialog-description`;
  return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(
    "button",
    {
      className: `${styles.trigger} ${triggerClassName != null ? triggerClassName : ""}`,
      onClick: () => {
        setInnerIsOpen(true);
        onOpen == null ? void 0 : onOpen();
      }
    },
    children
  ), /* @__PURE__ */ React.createElement(
    Dialog,
    {
      open: isOpen,
      onClose: handleClose,
      "aria-labelledby": titleId,
      "aria-describedby": descriptionId,
      classes: {
        container: styles.dialogContainer,
        paper: styles.dialogPaper
      }
    },
    /* @__PURE__ */ React.createElement(DialogTitle, { id: titleId, className: styles.dialogTitle }, "Authenticate with Coder"),
    /* @__PURE__ */ React.createElement(DialogContent, { className: styles.contentContainer }, /* @__PURE__ */ React.createElement(CoderAuthForm, { descriptionId })),
    /* @__PURE__ */ React.createElement(DialogActions, { className: styles.actionsRow }, /* @__PURE__ */ React.createElement(
      LinkButton,
      {
        to: "",
        onClick: handleClose,
        className: styles.closeButton,
        disableRipple: true
      },
      "Close"
    ))
  ));
}

const BACKSTAGE_APP_ROOT_ID = "#root";
const FALLBACK_UI_OVERRIDE_CLASS_NAME = "backstage-root-override";
const TOKEN_STORAGE_KEY = "coder-backstage-plugin/token";
const AUTH_GRACE_PERIOD_TIMEOUT_MS = 6e3;
const AuthTrackingContext = createContext(null);
const AuthStateContext = createContext(null);
const validAuthStatuses = [
  "authenticated",
  "distrustedWithGracePeriod"
];
function useAuthState() {
  const [authToken, setAuthToken] = useState(
    () => {
      var _a;
      return (_a = window.localStorage.getItem(TOKEN_STORAGE_KEY)) != null ? _a : "";
    }
  );
  const [readonlyInitialAuthToken] = useState(authToken);
  const [isInsideGracePeriod, setIsInsideGracePeriod] = useState(true);
  const coderClient = useApi(coderClientWrapperApiRef);
  const queryIsEnabled = authToken !== "";
  const authValidityQuery = useQuery({
    queryKey: [...sharedAuthQueryKey, authToken],
    queryFn: () => coderClient.syncToken(authToken),
    enabled: queryIsEnabled,
    keepPreviousData: queryIsEnabled,
    // Can't use !query.state.data because we want to refetch on undefined cases
    refetchOnWindowFocus: (query) => query.state.data !== false
  });
  const authState = generateAuthState({
    authToken,
    authValidityQuery,
    isInsideGracePeriod,
    initialAuthToken: readonlyInitialAuthToken
  });
  if (!isInsideGracePeriod && authState.status === "authenticated") {
    setIsInsideGracePeriod(true);
  }
  useEffect(() => {
    if (authState.status === "authenticated") {
      window.localStorage.setItem(TOKEN_STORAGE_KEY, authState.token);
    }
  }, [authState.status, authState.token]);
  useEffect(() => {
    if (authState.status !== "distrustedWithGracePeriod") {
      return void 0;
    }
    const distrustTimeoutId = window.setTimeout(() => {
      setIsInsideGracePeriod(false);
    }, AUTH_GRACE_PERIOD_TIMEOUT_MS);
    return () => window.clearTimeout(distrustTimeoutId);
  }, [authState.status]);
  const isAuthenticated = validAuthStatuses.includes(authState.status);
  const queryClient = useQueryClient();
  useEffect(() => {
    if (!isAuthenticated) {
      return void 0;
    }
    let isRevalidating = false;
    const revalidateTokenOnError = async (event) => {
      const queryError = event.query.state.error;
      const shouldRevalidate = isAuthenticated && !isRevalidating && BackstageHttpError.isInstance(queryError) && queryError.status === 401;
      if (!shouldRevalidate) {
        return;
      }
      isRevalidating = true;
      await queryClient.refetchQueries({ queryKey: sharedAuthQueryKey });
      isRevalidating = false;
    };
    const queryCache = queryClient.getQueryCache();
    const unsubscribe = queryCache.subscribe(revalidateTokenOnError);
    return unsubscribe;
  }, [queryClient, isAuthenticated]);
  const registerNewToken = useCallback((newToken) => {
    if (newToken !== "") {
      setAuthToken(newToken);
    }
  }, []);
  const unlinkToken = useCallback(() => {
    setAuthToken("");
    window.localStorage.removeItem(TOKEN_STORAGE_KEY);
    queryClient.removeQueries({ queryKey: [CODER_QUERY_KEY_PREFIX] });
  }, [queryClient]);
  return {
    ...authState,
    isAuthenticated,
    registerNewToken,
    unlinkToken
  };
}
function useAuthFallbackState() {
  const [isMounted, setIsMounted] = useState(false);
  useEffect(() => {
    setIsMounted(true);
  }, []);
  const [hasTrackers, setHasTrackers] = useState(false);
  const trackedComponentsRef = useRef(null);
  if (trackedComponentsRef.current === null) {
    trackedComponentsRef.current = /* @__PURE__ */ new Set();
  }
  const trackComponent = useCallback((componentId) => {
    const syncTrackerToUi = () => {
      setHasTrackers(trackedComponentsRef.current.size > 0);
    };
    trackedComponentsRef.current.add(componentId);
    syncTrackerToUi();
    return () => {
      trackedComponentsRef.current.delete(componentId);
      syncTrackerToUi();
    };
  }, []);
  return {
    trackComponent,
    hasNoAuthInputs: isMounted && !hasTrackers
  };
}
function useInternalCoderAuth() {
  const trackComponent = useContext(AuthTrackingContext);
  if (trackComponent === null) {
    throw new Error("Unable to retrieve state for displaying fallback auth UI");
  }
  const instanceId = useId();
  useEffect(() => {
    const cleanupTracking = trackComponent(instanceId);
    return cleanupTracking;
  }, [instanceId, trackComponent]);
  return useEndUserCoderAuth();
}
function useEndUserCoderAuth() {
  const authContextValue = useContext(AuthStateContext);
  if (authContextValue === null) {
    throw new Error("Cannot retrieve auth information from CoderProvider");
  }
  return authContextValue;
}
function generateAuthState({
  authToken,
  initialAuthToken,
  authValidityQuery,
  isInsideGracePeriod
}) {
  const isInitializing = initialAuthToken !== "" && authValidityQuery.isLoading && authValidityQuery.isFetching && !authValidityQuery.isFetchedAfterMount;
  if (isInitializing) {
    return {
      status: "initializing",
      token: void 0,
      error: void 0
    };
  }
  if (!authToken) {
    return {
      status: "tokenMissing",
      token: void 0,
      error: void 0
    };
  }
  if (BackstageHttpError.isInstance(authValidityQuery.error)) {
    const deploymentLikelyUnavailable = authValidityQuery.error.status === 504 || authValidityQuery.error.status === 200 && authValidityQuery.error.contentType !== "application/json";
    if (deploymentLikelyUnavailable) {
      return {
        status: "deploymentUnavailable",
        token: void 0,
        error: authValidityQuery.error
      };
    }
  }
  const isTokenValidFromPrevFetch = authValidityQuery.data === true;
  if (isTokenValidFromPrevFetch) {
    const canTrustAuthThisRender = authValidityQuery.isSuccess && !authValidityQuery.isPaused;
    if (canTrustAuthThisRender) {
      return {
        status: "authenticated",
        token: authToken,
        error: void 0
      };
    }
    if (isInsideGracePeriod) {
      return {
        status: "distrustedWithGracePeriod",
        token: authToken,
        error: void 0
      };
    }
    return {
      status: "distrusted",
      token: void 0,
      error: authValidityQuery.error
    };
  }
  const isAuthenticating = authValidityQuery.isLoading || authValidityQuery.isRefetching && (authValidityQuery.isError && authValidityQuery.data !== true || authValidityQuery.isSuccess && authValidityQuery.data === false);
  if (isAuthenticating) {
    return {
      status: "authenticating",
      token: void 0,
      error: authValidityQuery.error
    };
  }
  const isCoderDeploymentDown = authValidityQuery.error instanceof Error && authValidityQuery.error.name === "TimeoutError";
  if (isCoderDeploymentDown) {
    return {
      status: "distrusted",
      token: void 0,
      error: authValidityQuery.error
    };
  }
  if (authValidityQuery.isPaused) {
    return {
      status: "noInternetConnection",
      token: void 0,
      error: authValidityQuery.error
    };
  }
  return {
    status: "invalid",
    token: void 0,
    error: authValidityQuery.error
  };
}
const mainAppRoot = document.querySelector(BACKSTAGE_APP_ROOT_ID);
const useFallbackStyles = makeStyles((theme) => ({
  landmarkWrapper: ({ isDialogOpen }) => ({
    zIndex: isDialogOpen ? 0 : 9999,
    position: "fixed",
    bottom: theme.spacing(2),
    width: "100%",
    maxWidth: "fit-content",
    left: "50%",
    transform: "translateX(-50%)"
  }),
  dialogButton: {
    display: "flex",
    flexFlow: "row nowrap",
    columnGap: theme.spacing(1),
    alignItems: "center"
  },
  logo: {
    fill: theme.palette.primary.contrastText,
    width: theme.spacing(3)
  }
}));
function FallbackAuthUi() {
  const fallbackRef = useRef(null);
  useLayoutEffect(() => {
    var _a;
    const fallback = fallbackRef.current;
    const mainAppContainer = (_a = mainAppRoot == null ? void 0 : mainAppRoot.querySelector("main")) != null ? _a : null;
    if (fallback === null || mainAppContainer === null) {
      return void 0;
    }
    const overrideStyleNode = document.createElement("style");
    overrideStyleNode.type = "text/css";
    const liveAppStyles = getComputedStyle(mainAppContainer);
    const liveFallbackStyles = getComputedStyle(fallback);
    let prevPaddingBottom = void 0;
    const updatePaddingForFallbackUi = () => {
      const prevInnerHtml = overrideStyleNode.innerHTML;
      overrideStyleNode.innerHTML = "";
      const paddingBottomWithNoOverride = liveAppStyles.paddingBottom || "0px";
      if (paddingBottomWithNoOverride === prevPaddingBottom) {
        overrideStyleNode.innerHTML = prevInnerHtml;
        return;
      }
      const fallbackBottom = parseInt(liveFallbackStyles.bottom || "0", 10);
      const normalized = Number.isNaN(fallbackBottom) ? 0 : fallbackBottom;
      const paddingToAdd = fallback.offsetHeight + normalized;
      overrideStyleNode.innerHTML = `
        .${FALLBACK_UI_OVERRIDE_CLASS_NAME} {
          padding-bottom: calc(${paddingBottomWithNoOverride} + ${paddingToAdd}px) !important;
        }
      `;
      prevPaddingBottom = paddingBottomWithNoOverride;
    };
    const observer = new MutationObserver(updatePaddingForFallbackUi);
    observer.observe(document.head, { childList: true });
    observer.observe(mainAppContainer, {
      childList: false,
      subtree: false,
      attributes: true,
      attributeFilter: ["class", "style"]
    });
    document.head.append(overrideStyleNode);
    mainAppContainer.classList.add(FALLBACK_UI_OVERRIDE_CLASS_NAME);
    return () => {
      observer.disconnect();
      overrideStyleNode.remove();
      mainAppContainer.classList.remove(FALLBACK_UI_OVERRIDE_CLASS_NAME);
    };
  }, []);
  const hookId = useId();
  const [isDialogOpen, setIsDialogOpen] = useState(false);
  const styles = useFallbackStyles({ isDialogOpen });
  const landmarkId = `${hookId}-landmark`;
  const fallbackUi = /* @__PURE__ */ React.createElement(
    "section",
    {
      ref: fallbackRef,
      className: styles.landmarkWrapper,
      "aria-labelledby": landmarkId
    },
    /* @__PURE__ */ React.createElement("h2", { id: landmarkId, hidden: true }, "Authenticate with Coder to enable Coder plugin features"),
    /* @__PURE__ */ React.createElement(
      CoderAuthFormDialog,
      {
        open: isDialogOpen,
        onOpen: () => setIsDialogOpen(true),
        onClose: () => setIsDialogOpen(false),
        triggerClassName: styles.dialogButton
      },
      /* @__PURE__ */ React.createElement(CoderLogo, { className: styles.logo }),
      "Authenticate with Coder"
    )
  );
  return createPortal(fallbackUi, document.body);
}
const dummyTrackComponent = () => {
  return () => {
  };
};
const fallbackProviders = {
  hidden: ({ children }) => /* @__PURE__ */ React.createElement(AuthTrackingContext.Provider, { value: dummyTrackComponent }, children),
  assertive: ({ children, isAuthenticated }) => (
    // Don't need the live version of the tracker function if we're always
    // going to be showing the fallback auth input no matter what
    /* @__PURE__ */ React.createElement(AuthTrackingContext.Provider, { value: dummyTrackComponent }, children, !isAuthenticated && /* @__PURE__ */ React.createElement(FallbackAuthUi, null))
  ),
  // Have to give function a name to satisfy ES Lint (rules of hooks)
  restrained: function Restrained({ children, isAuthenticated }) {
    const { hasNoAuthInputs, trackComponent } = useAuthFallbackState();
    const needFallbackUi = !isAuthenticated && hasNoAuthInputs;
    return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(AuthTrackingContext.Provider, { value: trackComponent }, children), needFallbackUi && /* @__PURE__ */ React.createElement(AuthTrackingContext.Provider, { value: dummyTrackComponent }, /* @__PURE__ */ React.createElement(FallbackAuthUi, null)));
  }
};
function CoderAuthProvider({
  children,
  fallbackAuthUiMode = "restrained"
}) {
  const authState = useAuthState();
  const AuthFallbackProvider = fallbackProviders[fallbackAuthUiMode];
  return /* @__PURE__ */ React.createElement(AuthStateContext.Provider, { value: authState }, /* @__PURE__ */ React.createElement(AuthFallbackProvider, { isAuthenticated: authState.isAuthenticated }, children));
}

const AppConfigContext = createContext(null);
function useCoderAppConfig() {
  const value = useContext(AppConfigContext);
  if (value === null) {
    throw new Error(
      `Hook ${useCoderAppConfig.name} must be called from a CoderProvider component`
    );
  }
  return value;
}
const CoderAppConfigProvider = ({
  children,
  appConfig
}) => {
  return /* @__PURE__ */ React.createElement(AppConfigContext.Provider, { value: appConfig }, children);
};

const FallbackUi = () => {
  return /* @__PURE__ */ React.createElement("p", null, "Error encountered. Please check browser console.");
};
class ErrorBoundaryCore extends Component {
  static getDerivedStateFromError() {
    return { hasError: true };
  }
  constructor(props) {
    super(props);
    this.state = { hasError: false };
  }
  componentDidCatch(error, errorInfo) {
    this.props.onError(error, errorInfo.componentStack || "no details");
  }
  render() {
    const { children, fallbackUi } = this.props;
    return /* @__PURE__ */ React.createElement(React.Fragment, null, this.state.hasError ? fallbackUi : children);
  }
}
const CoderErrorBoundary$1 = ({
  children,
  fallbackUi
}) => {
  const errorApi = useApi(errorApiRef);
  const fallbackContent = fallbackUi != null ? fallbackUi : /* @__PURE__ */ React.createElement(FallbackUi, null);
  const onError = (error, componentStack) => {
    var _a;
    let errorToLog;
    if (error instanceof ValiError) {
      const logs = error.issues.map((issue) => issue.message).join(", ");
      errorToLog = new Error(logs);
    } else {
      errorToLog = new Error();
      errorToLog.message = error.message;
      errorToLog.name = error.name;
    }
    errorToLog.stack = `${(_a = error.stack) != null ? _a : ""}

React Component stack:
${componentStack}`;
    errorApi.post(errorToLog, {
      hidden: false
    });
  };
  return /* @__PURE__ */ React.createElement(ErrorBoundaryCore, { fallbackUi: fallbackContent, onError }, children);
};

const MAX_FETCH_FAILURES = 3;
const shouldRetryRequest = (failureCount, error) => {
  const isBelowThreshold = failureCount < MAX_FETCH_FAILURES;
  if (!BackstageHttpError.isInstance(error)) {
    return isBelowThreshold;
  }
  const isAuthenticationError = error.status === 401;
  const isLikelyProxyConfigurationError = error.status === 504 || error.status === 200 && error.contentType !== "application/json";
  return !isAuthenticationError && !isLikelyProxyConfigurationError && isBelowThreshold;
};
const defaultClient = new QueryClient({
  defaultOptions: {
    queries: {
      retry: shouldRetryRequest
    },
    mutations: {
      retry: shouldRetryRequest
    }
  }
});
const CoderProvider$1 = ({
  children,
  appConfig,
  fallbackAuthUiMode = "restrained",
  queryClient = defaultClient
}) => {
  return /* @__PURE__ */ React.createElement(CoderErrorBoundary$1, null, /* @__PURE__ */ React.createElement(QueryClientProvider, { client: queryClient }, /* @__PURE__ */ React.createElement(CoderAppConfigProvider, { appConfig }, /* @__PURE__ */ React.createElement(CoderAuthProvider, { fallbackAuthUiMode }, children))));
};

const workspaceCreationModeSchema = optional(
  union(
    [literal("manual"), literal("auto")],
    "If defined, createMode must be 'manual' or 'auto'"
  )
);
const yamlConfigSchema = union([
  undefined_(),
  object({
    templateName: optional(string()),
    mode: workspaceCreationModeSchema,
    params: optional(
      record(
        string(),
        // Defining record value with undefined case as a safety net if user
        // hasn't or can't turn on the noUncheckedIndexedAccess compiler option
        union([string(), undefined_()]),
        "If defined, params must be JSON-serializable as Record<string, string>"
      )
    )
  })
]);
function compileCoderConfig(appConfig, rawYamlConfig, repoUrl) {
  var _a, _b, _c, _d;
  const { workspaces, deployment } = appConfig;
  const yamlConfig = parse(yamlConfigSchema, rawYamlConfig);
  const mode = (_b = (_a = yamlConfig == null ? void 0 : yamlConfig.mode) != null ? _a : workspaces.defaultMode) != null ? _b : "manual";
  const templateName = (_c = yamlConfig == null ? void 0 : yamlConfig.templateName) != null ? _c : workspaces.defaultTemplateName;
  const urlParams = new URLSearchParams({ mode });
  const compiledParams = {};
  const paramsPrecedence = [workspaces.params, (_d = yamlConfig == null ? void 0 : yamlConfig.params) != null ? _d : {}];
  for (const params of paramsPrecedence) {
    for (const key in params) {
      if (!params.hasOwnProperty(key)) {
        continue;
      }
      const value = params[key];
      if (typeof value === "string") {
        compiledParams[key] = value;
        urlParams.set(`param.${key}`, value);
      }
    }
  }
  let cleanedRepoUrl = repoUrl;
  if (repoUrl !== void 0) {
    cleanedRepoUrl = repoUrl.replace(/\/tree\/[\w._-]+\/?$/, "");
    for (const key of workspaces.repoUrlParamKeys) {
      compiledParams[key] = cleanedRepoUrl;
      urlParams.set(`param.${key}`, cleanedRepoUrl);
    }
  }
  let creationUrl = void 0;
  if (templateName) {
    const safeTemplate = encodeURIComponent(templateName);
    creationUrl = `${deployment.accessUrl}/templates/${safeTemplate}/workspace?${urlParams.toString()}`;
  }
  return {
    mode,
    creationUrl,
    templateName,
    repoUrl: cleanedRepoUrl,
    isReadingEntityData: yamlConfig !== void 0,
    repoUrlParamKeys: workspaces.repoUrlParamKeys,
    params: compiledParams
  };
}
function useCoderWorkspacesConfig({
  readEntityData = false
}) {
  const appConfig = useCoderAppConfig();
  const { rawYaml, repoUrl } = useDynamicEntity(readEntityData);
  return useMemo(
    () => compileCoderConfig(appConfig, rawYaml, repoUrl),
    // Backstage seems to have stabilized the value of rawYamlConfig, so even
    // when it's an object, useMemo shouldn't re-run unnecessarily
    [appConfig, rawYaml, repoUrl]
  );
}
function useDynamicEntity(readEntityData) {
  var _a;
  const [initialReadSetting] = useState(readEntityData);
  if (readEntityData !== initialReadSetting) {
    throw new Error(
      'The value of "readEntityData" is not allowed to change across re-renders'
    );
  }
  let rawYaml = void 0;
  let repoUrl = void 0;
  if (readEntityData) {
    const { entity } = useEntity();
    const sourceControlApi = useApi(scmIntegrationsApiRef);
    const repoData = getEntitySourceLocation(entity, sourceControlApi);
    rawYaml = (_a = entity.spec) == null ? void 0 : _a.coder;
    repoUrl = repoData == null ? void 0 : repoData.locationTargetUrl;
  }
  return { rawYaml, repoUrl };
}

function useCoderApi() {
  const { api } = useApi(coderClientWrapperApiRef);
  return api;
}

function useCoderWorkspacesQuery({
  coderQuery,
  workspacesConfig
}) {
  const api = useCoderApi();
  const auth = useInternalCoderAuth();
  const hasRepoData = workspacesConfig && workspacesConfig.repoUrl;
  const queryOptions = hasRepoData ? workspacesByRepo({ auth, api, coderQuery, workspacesConfig }) : workspaces({ auth, api, coderQuery });
  return useQuery(queryOptions);
}

const useStyles$1 = makeStyles((theme) => ({
  root: {
    color: theme.palette.type,
    backgroundColor: theme.palette.background.paper,
    padding: theme.spacing(2),
    borderRadius: theme.shape.borderRadius,
    boxShadow: theme.shadows[1]
  },
  headerContent: {
    // Ideally wouldn't be using hard-coded font sizes, but couldn't figure out
    // how to use the theme.typography property, especially since not all
    // sub-properties have font sizes defined
    fontSize: "1.5rem",
    color: theme.palette.text.primary,
    fontWeight: 700,
    borderBottom: `1px solid ${theme.palette.divider}`,
    // Margins and padding are a bit wonky to support full-bleed layouts
    marginLeft: `-${theme.spacing(2)}px`,
    marginRight: `-${theme.spacing(2)}px`,
    padding: `0 ${theme.spacing(2)}px ${theme.spacing(2)}px`
  }
}));
const A11yInfoCard = forwardRef(
  (props, ref) => {
    const { className, children, headerContent, ...delegatedProps } = props;
    const styles = useStyles$1();
    return /* @__PURE__ */ React.createElement(
      "div",
      {
        ref,
        className: `${styles.root} ${className != null ? className : ""}`,
        ...delegatedProps
      },
      headerContent !== void 0 && /* @__PURE__ */ React.createElement("div", { className: styles.headerContent }, headerContent),
      children
    );
  }
);

const useStyles = makeStyles((theme) => ({
  root: {
    paddingTop: theme.spacing(6),
    paddingBottom: theme.spacing(6)
  }
}));
function CoderAuthFormCardWrapper({
  children,
  headerContent,
  descriptionId,
  ...delegatedCardProps
}) {
  const { isAuthenticated } = useInternalCoderAuth();
  const styles = useStyles();
  return /* @__PURE__ */ React.createElement(
    A11yInfoCard,
    {
      headerContent: (
        // Can't wrap headerContent in Fragment in case headerContent should be
        // undefined when authenticated
        isAuthenticated ? headerContent : /* @__PURE__ */ React.createElement(React.Fragment, null, "Authenticate with Coder")
      ),
      ...delegatedCardProps
    },
    isAuthenticated ? /* @__PURE__ */ React.createElement(React.Fragment, null, children) : /* @__PURE__ */ React.createElement("div", { className: styles.root }, /* @__PURE__ */ React.createElement(CoderAuthForm, { descriptionId }))
  );
}

const CardContext = createContext(null);
const InnerRoot = ({
  children,
  className,
  headerContent,
  queryFilter: outerFilter,
  onFilterChange: onOuterFilterChange,
  defaultQueryFilter = "owner:me",
  readEntityData = false,
  ...delegatedProps
}) => {
  const [innerFilter, setInnerFilter] = useState(defaultQueryFilter);
  const activeFilter = outerFilter != null ? outerFilter : innerFilter;
  const workspacesConfig = useCoderWorkspacesConfig({ readEntityData });
  const workspacesQuery = useCoderWorkspacesQuery({
    workspacesConfig,
    coderQuery: activeFilter
  });
  const hookId = useId();
  const headerId = `${hookId}-header`;
  return /* @__PURE__ */ React.createElement(
    CardContext.Provider,
    {
      value: {
        headerId,
        workspacesQuery,
        workspacesConfig,
        queryFilter: activeFilter,
        onFilterChange: (newFilter) => {
          setInnerFilter(newFilter);
          onOuterFilterChange == null ? void 0 : onOuterFilterChange(newFilter);
        }
      }
    },
    /* @__PURE__ */ React.createElement(
      CoderAuthFormCardWrapper,
      {
        role: "search",
        headerContent,
        "aria-labelledby": headerId,
        ...delegatedProps
      },
      /* @__PURE__ */ React.createElement("div", { role: "form" }, children)
    )
  );
};
function Root(props) {
  var _a;
  const renderKey = String((_a = props.readEntityData) != null ? _a : false);
  return /* @__PURE__ */ React.createElement(InnerRoot, { key: renderKey, ...props });
}
function useWorkspacesCardContext() {
  const contextValue = useContext(CardContext);
  if (contextValue === null) {
    throw new Error(
      `Not calling ${useWorkspacesCardContext.name} from inside a ${Root.name}`
    );
  }
  return contextValue;
}

function useCoderQuery(queryOptions) {
  var _a, _b, _c, _d;
  const queryClient = useQueryClient();
  const { isAuthenticated } = useEndUserCoderAuth();
  const coderApi = useCoderApi();
  let patchedQueryKey = queryOptions.queryKey;
  if (patchedQueryKey === void 0 || patchedQueryKey[0] !== CODER_QUERY_KEY_PREFIX) {
    const baseKey = (_a = queryOptions.queryKey) != null ? _a : queryClient.defaultQueryOptions().queryKey;
    if (baseKey === void 0) {
      throw new Error("No queryKey value provided to useCoderQuery");
    }
    patchedQueryKey = [
      CODER_QUERY_KEY_PREFIX,
      ...baseKey
    ];
  }
  const patchedOptions = {
    ...queryOptions,
    queryKey: patchedQueryKey,
    enabled: isAuthenticated && ((_b = queryOptions.enabled) != null ? _b : true),
    keepPreviousData: isAuthenticated && ((_c = queryOptions.keepPreviousData) != null ? _c : false),
    refetchIntervalInBackground: isAuthenticated && ((_d = queryOptions.refetchIntervalInBackground) != null ? _d : false),
    queryFn: async (context) => {
      if (!isAuthenticated) {
        throw new Error("Cannot complete request - user is not authenticated");
      }
      return queryOptions.queryFn({ ...context, coderApi });
    },
    refetchInterval: (data, query) => {
      if (!isAuthenticated) {
        return false;
      }
      const externalRefetchInterval = queryOptions.refetchInterval;
      if (typeof externalRefetchInterval !== "function") {
        return externalRefetchInterval != null ? externalRefetchInterval : false;
      }
      return externalRefetchInterval(data, query);
    },
    refetchOnMount: (query) => {
      if (!isAuthenticated) {
        return false;
      }
      const externalRefetchOnMount = queryOptions.refetchOnMount;
      if (typeof externalRefetchOnMount !== "function") {
        return externalRefetchOnMount != null ? externalRefetchOnMount : true;
      }
      return externalRefetchOnMount(query);
    },
    retry: (failureCount, error) => {
      if (!isAuthenticated) {
        return false;
      }
      const externalRetry = queryOptions.retry;
      if (typeof externalRetry === "number") {
        const normalized = Number.isInteger(externalRetry) ? Math.max(1, externalRetry) : DEFAULT_TANSTACK_QUERY_RETRY_COUNT;
        return failureCount < normalized;
      }
      if (typeof externalRetry !== "function") {
        return externalRetry ? externalRetry : failureCount < DEFAULT_TANSTACK_QUERY_RETRY_COUNT;
      }
      return externalRetry(failureCount, error);
    }
  };
  return useQuery(patchedOptions);
}

const coderPlugin = createPlugin({
  id: "coder",
  routes: { root: rootRouteRef },
  apis: [
    createApiFactory({
      api: urlSyncApiRef,
      deps: {
        discoveryApi: discoveryApiRef,
        configApi: configApiRef
      },
      factory: ({ discoveryApi, configApi }) => {
        return new UrlSync({
          apis: { discoveryApi, configApi }
        });
      }
    }),
    createApiFactory({
      api: coderClientWrapperApiRef,
      deps: {
        urlSync: urlSyncApiRef,
        identityApi: identityApiRef
      },
      factory: ({ urlSync, identityApi }) => {
        return new CoderClientWrapper({
          apis: { urlSync, identityApi }
        });
      }
    })
  ]
});
const CoderProvider = coderPlugin.provide(
  createComponentExtension({
    name: "CoderProvider",
    component: {
      lazy: () => import('./index-550eb3aa.esm.js').then((m) => m.CoderProvider)
    }
  })
);
const CoderErrorBoundary = coderPlugin.provide(
  createComponentExtension({
    name: "CoderErrorBoundary",
    component: {
      lazy: () => import('./index-ad855bd8.esm.js').then(
        (m) => m.CoderErrorBoundary
      )
    }
  })
);
const CoderWorkspacesCard = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then(
        (m) => m.CoderWorkspacesCard
      )
    }
  })
);
const CoderWorkspacesCardCreateWorkspacesLink = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard.CreateWorkspacesLink",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then(
        (m) => m.CreateWorkspaceLink
      )
    }
  })
);
const CoderWorkspacesCardExtraActionsButton = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard.ExtraActionsButton",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then(
        (m) => m.ExtraActionsButton
      )
    }
  })
);
const CoderWorkspacesCardHeaderRow = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard.HeaderRow",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then((m) => m.HeaderRow)
    }
  })
);
const CoderWorkspacesCardRoot = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard.Root",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then((m) => m.Root)
    }
  })
);
const CoderWorkspacesCardSearchBox = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard.SearchBox",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then((m) => m.SearchBox)
    }
  })
);
const CoderWorkspacesCardWorkspacesList = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard.WorkspacesList",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then((m) => m.WorkspacesList)
    }
  })
);
const CoderWorkspacesCardWorkspacesListIcon = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard.WorkspacesListIcon",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then(
        (m) => m.WorkspacesListIcon
      )
    }
  })
);
const CoderWorkspacesCardWorkspacesListItem = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard.WorkspacesListItem",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then(
        (m) => m.WorkspacesListItem
      )
    }
  })
);
const CoderWorkspacesReminderAccordion = coderPlugin.provide(
  createComponentExtension({
    name: "CoderWorkspacesCard.ReminderAccordion",
    component: {
      lazy: () => import('./index-db2e21de.esm.js').then(
        (m) => m.ReminderAccordion
      )
    }
  })
);

export { AuthTrackingContext as A, useCoderWorkspacesConfig as B, CoderAuthProvider as C, useCoderApi as D, useCoderQuery as E, CODER_QUERY_KEY_PREFIX as F, Root as R, VisuallyHidden as V, AuthStateContext as a, useEndUserCoderAuth as b, useCoderAppConfig as c, dummyTrackComponent as d, CoderAppConfigProvider as e, CoderProvider$1 as f, CoderErrorBoundary$1 as g, useWorkspacesCardContext as h, useId as i, urlSyncApiRef as j, CoderLogo as k, CardContext as l, coderPlugin as m, CoderProvider as n, CoderErrorBoundary as o, CoderWorkspacesCard as p, CoderWorkspacesCardCreateWorkspacesLink as q, CoderWorkspacesCardExtraActionsButton as r, CoderWorkspacesCardHeaderRow as s, CoderWorkspacesCardRoot as t, useInternalCoderAuth as u, CoderWorkspacesCardSearchBox as v, CoderWorkspacesCardWorkspacesList as w, CoderWorkspacesCardWorkspacesListIcon as x, CoderWorkspacesCardWorkspacesListItem as y, CoderWorkspacesReminderAccordion as z };
//# sourceMappingURL=index-e8bd86d5.esm.js.map
